
from gogoproto import gogo_pb2 as _gogo_pb2
from tendermint.crypto import keys_pb2 as _keys_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union
DESCRIPTOR: _descriptor.FileDescriptor

class SimpleValidator(_message.Message):
    __slots__ = ['pub_key', 'voting_power']
    PUB_KEY_FIELD_NUMBER: _ClassVar[int]
    VOTING_POWER_FIELD_NUMBER: _ClassVar[int]
    pub_key: _keys_pb2.PublicKey
    voting_power: int

    def __init__(self, pub_key: _Optional[_Union[(_keys_pb2.PublicKey, _Mapping)]]=..., voting_power: _Optional[int]=...) -> None:
        ...

class Validator(_message.Message):
    __slots__ = ['address', 'proposer_priority', 'pub_key', 'voting_power']
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    PROPOSER_PRIORITY_FIELD_NUMBER: _ClassVar[int]
    PUB_KEY_FIELD_NUMBER: _ClassVar[int]
    VOTING_POWER_FIELD_NUMBER: _ClassVar[int]
    address: bytes
    proposer_priority: int
    pub_key: _keys_pb2.PublicKey
    voting_power: int

    def __init__(self, address: _Optional[bytes]=..., pub_key: _Optional[_Union[(_keys_pb2.PublicKey, _Mapping)]]=..., voting_power: _Optional[int]=..., proposer_priority: _Optional[int]=...) -> None:
        ...

class ValidatorSet(_message.Message):
    __slots__ = ['proposer', 'total_voting_power', 'validators']
    PROPOSER_FIELD_NUMBER: _ClassVar[int]
    TOTAL_VOTING_POWER_FIELD_NUMBER: _ClassVar[int]
    VALIDATORS_FIELD_NUMBER: _ClassVar[int]
    proposer: Validator
    total_voting_power: int
    validators: _containers.RepeatedCompositeFieldContainer[Validator]

    def __init__(self, validators: _Optional[_Iterable[_Union[(Validator, _Mapping)]]]=..., proposer: _Optional[_Union[(Validator, _Mapping)]]=..., total_voting_power: _Optional[int]=...) -> None:
        ...




from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Optional as _Optional
DESCRIPTOR: _descriptor.FileDescriptor

class CompactBitArray(_message.Message):
    __slots__ = ['elems', 'extra_bits_stored']
    ELEMS_FIELD_NUMBER: _ClassVar[int]
    EXTRA_BITS_STORED_FIELD_NUMBER: _ClassVar[int]
    elems: bytes
    extra_bits_stored: int

    def __init__(self, extra_bits_stored: _Optional[int]=..., elems: _Optional[bytes]=...) -> None:
        ...

class MultiSignature(_message.Message):
    __slots__ = ['signatures']
    SIGNATURES_FIELD_NUMBER: _ClassVar[int]
    signatures: _containers.RepeatedScalarFieldContainer[bytes]

    def __init__(self, signatures: _Optional[_Iterable[bytes]]=...) -> None:
        ...




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from ....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from ....google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from ....cosmos.staking.v1beta1 import staking_pb2 as cosmos_dot_staking_dot_v1beta1_dot_staking__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n"cosmos/staking/v1beta1/query.proto\x12\x16cosmos.staking.v1beta1\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a$cosmos/staking/v1beta1/staking.proto"d\n\x16QueryValidatorsRequest\x12\x0e\n\x06status\x18\x01 \x01(\t\x12:\n\npagination\x18\x02 \x01(\x0b2&.cosmos.base.query.v1beta1.PageRequest"\x93\x01\n\x17QueryValidatorsResponse\x12;\n\nvalidators\x18\x01 \x03(\x0b2!.cosmos.staking.v1beta1.ValidatorB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b2\'.cosmos.base.query.v1beta1.PageResponse"/\n\x15QueryValidatorRequest\x12\x16\n\x0evalidator_addr\x18\x01 \x01(\t"T\n\x16QueryValidatorResponse\x12:\n\tvalidator\x18\x01 \x01(\x0b2!.cosmos.staking.v1beta1.ValidatorB\x04\xc8\xde\x1f\x00"v\n QueryValidatorDelegationsRequest\x12\x16\n\x0evalidator_addr\x18\x01 \x01(\t\x12:\n\npagination\x18\x02 \x01(\x0b2&.cosmos.base.query.v1beta1.PageRequest"\xc7\x01\n!QueryValidatorDelegationsResponse\x12e\n\x14delegation_responses\x18\x01 \x03(\x0b2*.cosmos.staking.v1beta1.DelegationResponseB\x1b\xc8\xde\x1f\x00\xaa\xdf\x1f\x13DelegationResponses\x12;\n\npagination\x18\x02 \x01(\x0b2\'.cosmos.base.query.v1beta1.PageResponse"\x7f\n)QueryValidatorUnbondingDelegationsRequest\x12\x16\n\x0evalidator_addr\x18\x01 \x01(\t\x12:\n\npagination\x18\x02 \x01(\x0b2&.cosmos.base.query.v1beta1.PageRequest"\xb9\x01\n*QueryValidatorUnbondingDelegationsResponse\x12N\n\x13unbonding_responses\x18\x01 \x03(\x0b2+.cosmos.staking.v1beta1.UnbondingDelegationB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b2\'.cosmos.base.query.v1beta1.PageResponse"R\n\x16QueryDelegationRequest\x12\x16\n\x0edelegator_addr\x18\x01 \x01(\t\x12\x16\n\x0evalidator_addr\x18\x02 \x01(\t:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00"b\n\x17QueryDelegationResponse\x12G\n\x13delegation_response\x18\x01 \x01(\x0b2*.cosmos.staking.v1beta1.DelegationResponse"[\n\x1fQueryUnbondingDelegationRequest\x12\x16\n\x0edelegator_addr\x18\x01 \x01(\t\x12\x16\n\x0evalidator_addr\x18\x02 \x01(\t:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00"e\n QueryUnbondingDelegationResponse\x12A\n\x06unbond\x18\x01 \x01(\x0b2+.cosmos.staking.v1beta1.UnbondingDelegationB\x04\xc8\xde\x1f\x00"\x80\x01\n QueryDelegatorDelegationsRequest\x12\x16\n\x0edelegator_addr\x18\x01 \x01(\t\x12:\n\npagination\x18\x02 \x01(\x0b2&.cosmos.base.query.v1beta1.PageRequest:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00"\xb0\x01\n!QueryDelegatorDelegationsResponse\x12N\n\x14delegation_responses\x18\x01 \x03(\x0b2*.cosmos.staking.v1beta1.DelegationResponseB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b2\'.cosmos.base.query.v1beta1.PageResponse"\x89\x01\n)QueryDelegatorUnbondingDelegationsRequest\x12\x16\n\x0edelegator_addr\x18\x01 \x01(\t\x12:\n\npagination\x18\x02 \x01(\x0b2&.cosmos.base.query.v1beta1.PageRequest:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00"\xb9\x01\n*QueryDelegatorUnbondingDelegationsResponse\x12N\n\x13unbonding_responses\x18\x01 \x03(\x0b2+.cosmos.staking.v1beta1.UnbondingDelegationB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b2\'.cosmos.base.query.v1beta1.PageResponse"\xb1\x01\n\x19QueryRedelegationsRequest\x12\x16\n\x0edelegator_addr\x18\x01 \x01(\t\x12\x1a\n\x12src_validator_addr\x18\x02 \x01(\t\x12\x1a\n\x12dst_validator_addr\x18\x03 \x01(\t\x12:\n\npagination\x18\x04 \x01(\x0b2&.cosmos.base.query.v1beta1.PageRequest:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00"\xad\x01\n\x1aQueryRedelegationsResponse\x12R\n\x16redelegation_responses\x18\x01 \x03(\x0b2,.cosmos.staking.v1beta1.RedelegationResponseB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b2\'.cosmos.base.query.v1beta1.PageResponse"\x7f\n\x1fQueryDelegatorValidatorsRequest\x12\x16\n\x0edelegator_addr\x18\x01 \x01(\t\x12:\n\npagination\x18\x02 \x01(\x0b2&.cosmos.base.query.v1beta1.PageRequest:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00"\x9c\x01\n QueryDelegatorValidatorsResponse\x12;\n\nvalidators\x18\x01 \x03(\x0b2!.cosmos.staking.v1beta1.ValidatorB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b2\'.cosmos.base.query.v1beta1.PageResponse"Z\n\x1eQueryDelegatorValidatorRequest\x12\x16\n\x0edelegator_addr\x18\x01 \x01(\t\x12\x16\n\x0evalidator_addr\x18\x02 \x01(\t:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00"]\n\x1fQueryDelegatorValidatorResponse\x12:\n\tvalidator\x18\x01 \x01(\x0b2!.cosmos.staking.v1beta1.ValidatorB\x04\xc8\xde\x1f\x00",\n\x1aQueryHistoricalInfoRequest\x12\x0e\n\x06height\x18\x01 \x01(\x03"S\n\x1bQueryHistoricalInfoResponse\x124\n\x04hist\x18\x01 \x01(\x0b2&.cosmos.staking.v1beta1.HistoricalInfo"\x12\n\x10QueryPoolRequest"E\n\x11QueryPoolResponse\x120\n\x04pool\x18\x01 \x01(\x0b2\x1c.cosmos.staking.v1beta1.PoolB\x04\xc8\xde\x1f\x00"\x14\n\x12QueryParamsRequest"K\n\x13QueryParamsResponse\x124\n\x06params\x18\x01 \x01(\x0b2\x1e.cosmos.staking.v1beta1.ParamsB\x04\xc8\xde\x1f\x002\xea\x15\n\x05Query\x12\x99\x01\n\nValidators\x12..cosmos.staking.v1beta1.QueryValidatorsRequest\x1a/.cosmos.staking.v1beta1.QueryValidatorsResponse"*\x82\xd3\xe4\x93\x02$\x12"/cosmos/staking/v1beta1/validators\x12\xa7\x01\n\tValidator\x12-.cosmos.staking.v1beta1.QueryValidatorRequest\x1a..cosmos.staking.v1beta1.QueryValidatorResponse";\x82\xd3\xe4\x93\x025\x123/cosmos/staking/v1beta1/validators/{validator_addr}\x12\xd4\x01\n\x14ValidatorDelegations\x128.cosmos.staking.v1beta1.QueryValidatorDelegationsRequest\x1a9.cosmos.staking.v1beta1.QueryValidatorDelegationsResponse"G\x82\xd3\xe4\x93\x02A\x12?/cosmos/staking/v1beta1/validators/{validator_addr}/delegations\x12\xf9\x01\n\x1dValidatorUnbondingDelegations\x12A.cosmos.staking.v1beta1.QueryValidatorUnbondingDelegationsRequest\x1aB.cosmos.staking.v1beta1.QueryValidatorUnbondingDelegationsResponse"Q\x82\xd3\xe4\x93\x02K\x12I/cosmos/staking/v1beta1/validators/{validator_addr}/unbonding_delegations\x12\xc7\x01\n\nDelegation\x12..cosmos.staking.v1beta1.QueryDelegationRequest\x1a/.cosmos.staking.v1beta1.QueryDelegationResponse"X\x82\xd3\xe4\x93\x02R\x12P/cosmos/staking/v1beta1/validators/{validator_addr}/delegations/{delegator_addr}\x12\xf7\x01\n\x13UnbondingDelegation\x127.cosmos.staking.v1beta1.QueryUnbondingDelegationRequest\x1a8.cosmos.staking.v1beta1.QueryUnbondingDelegationResponse"m\x82\xd3\xe4\x93\x02g\x12e/cosmos/staking/v1beta1/validators/{validator_addr}/delegations/{delegator_addr}/unbonding_delegation\x12\xc9\x01\n\x14DelegatorDelegations\x128.cosmos.staking.v1beta1.QueryDelegatorDelegationsRequest\x1a9.cosmos.staking.v1beta1.QueryDelegatorDelegationsResponse"<\x82\xd3\xe4\x93\x026\x124/cosmos/staking/v1beta1/delegations/{delegator_addr}\x12\xf9\x01\n\x1dDelegatorUnbondingDelegations\x12A.cosmos.staking.v1beta1.QueryDelegatorUnbondingDelegationsRequest\x1aB.cosmos.staking.v1beta1.QueryDelegatorUnbondingDelegationsResponse"Q\x82\xd3\xe4\x93\x02K\x12I/cosmos/staking/v1beta1/delegators/{delegator_addr}/unbonding_delegations\x12\xc1\x01\n\rRedelegations\x121.cosmos.staking.v1beta1.QueryRedelegationsRequest\x1a2.cosmos.staking.v1beta1.QueryRedelegationsResponse"I\x82\xd3\xe4\x93\x02C\x12A/cosmos/staking/v1beta1/delegators/{delegator_addr}/redelegations\x12\xd0\x01\n\x13DelegatorValidators\x127.cosmos.staking.v1beta1.QueryDelegatorValidatorsRequest\x1a8.cosmos.staking.v1beta1.QueryDelegatorValidatorsResponse"F\x82\xd3\xe4\x93\x02@\x12>/cosmos/staking/v1beta1/delegators/{delegator_addr}/validators\x12\xde\x01\n\x12DelegatorValidator\x126.cosmos.staking.v1beta1.QueryDelegatorValidatorRequest\x1a7.cosmos.staking.v1beta1.QueryDelegatorValidatorResponse"W\x82\xd3\xe4\x93\x02Q\x12O/cosmos/staking/v1beta1/delegators/{delegator_addr}/validators/{validator_addr}\x12\xb3\x01\n\x0eHistoricalInfo\x122.cosmos.staking.v1beta1.QueryHistoricalInfoRequest\x1a3.cosmos.staking.v1beta1.QueryHistoricalInfoResponse"8\x82\xd3\xe4\x93\x022\x120/cosmos/staking/v1beta1/historical_info/{height}\x12\x81\x01\n\x04Pool\x12(.cosmos.staking.v1beta1.QueryPoolRequest\x1a).cosmos.staking.v1beta1.QueryPoolResponse"$\x82\xd3\xe4\x93\x02\x1e\x12\x1c/cosmos/staking/v1beta1/pool\x12\x89\x01\n\x06Params\x12*.cosmos.staking.v1beta1.QueryParamsRequest\x1a+.cosmos.staking.v1beta1.QueryParamsResponse"&\x82\xd3\xe4\x93\x02 \x12\x1e/cosmos/staking/v1beta1/paramsB.Z,github.com/cosmos/cosmos-sdk/x/staking/typesb\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.staking.v1beta1.query_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z,github.com/cosmos/cosmos-sdk/x/staking/types'
    _QUERYVALIDATORSRESPONSE.fields_by_name['validators']._options = None
    _QUERYVALIDATORSRESPONSE.fields_by_name['validators']._serialized_options = b'\xc8\xde\x1f\x00'
    _QUERYVALIDATORRESPONSE.fields_by_name['validator']._options = None
    _QUERYVALIDATORRESPONSE.fields_by_name['validator']._serialized_options = b'\xc8\xde\x1f\x00'
    _QUERYVALIDATORDELEGATIONSRESPONSE.fields_by_name['delegation_responses']._options = None
    _QUERYVALIDATORDELEGATIONSRESPONSE.fields_by_name['delegation_responses']._serialized_options = b'\xc8\xde\x1f\x00\xaa\xdf\x1f\x13DelegationResponses'
    _QUERYVALIDATORUNBONDINGDELEGATIONSRESPONSE.fields_by_name['unbonding_responses']._options = None
    _QUERYVALIDATORUNBONDINGDELEGATIONSRESPONSE.fields_by_name['unbonding_responses']._serialized_options = b'\xc8\xde\x1f\x00'
    _QUERYDELEGATIONREQUEST._options = None
    _QUERYDELEGATIONREQUEST._serialized_options = b'\xe8\xa0\x1f\x00\x88\xa0\x1f\x00'
    _QUERYUNBONDINGDELEGATIONREQUEST._options = None
    _QUERYUNBONDINGDELEGATIONREQUEST._serialized_options = b'\xe8\xa0\x1f\x00\x88\xa0\x1f\x00'
    _QUERYUNBONDINGDELEGATIONRESPONSE.fields_by_name['unbond']._options = None
    _QUERYUNBONDINGDELEGATIONRESPONSE.fields_by_name['unbond']._serialized_options = b'\xc8\xde\x1f\x00'
    _QUERYDELEGATORDELEGATIONSREQUEST._options = None
    _QUERYDELEGATORDELEGATIONSREQUEST._serialized_options = b'\xe8\xa0\x1f\x00\x88\xa0\x1f\x00'
    _QUERYDELEGATORDELEGATIONSRESPONSE.fields_by_name['delegation_responses']._options = None
    _QUERYDELEGATORDELEGATIONSRESPONSE.fields_by_name['delegation_responses']._serialized_options = b'\xc8\xde\x1f\x00'
    _QUERYDELEGATORUNBONDINGDELEGATIONSREQUEST._options = None
    _QUERYDELEGATORUNBONDINGDELEGATIONSREQUEST._serialized_options = b'\xe8\xa0\x1f\x00\x88\xa0\x1f\x00'
    _QUERYDELEGATORUNBONDINGDELEGATIONSRESPONSE.fields_by_name['unbonding_responses']._options = None
    _QUERYDELEGATORUNBONDINGDELEGATIONSRESPONSE.fields_by_name['unbonding_responses']._serialized_options = b'\xc8\xde\x1f\x00'
    _QUERYREDELEGATIONSREQUEST._options = None
    _QUERYREDELEGATIONSREQUEST._serialized_options = b'\xe8\xa0\x1f\x00\x88\xa0\x1f\x00'
    _QUERYREDELEGATIONSRESPONSE.fields_by_name['redelegation_responses']._options = None
    _QUERYREDELEGATIONSRESPONSE.fields_by_name['redelegation_responses']._serialized_options = b'\xc8\xde\x1f\x00'
    _QUERYDELEGATORVALIDATORSREQUEST._options = None
    _QUERYDELEGATORVALIDATORSREQUEST._serialized_options = b'\xe8\xa0\x1f\x00\x88\xa0\x1f\x00'
    _QUERYDELEGATORVALIDATORSRESPONSE.fields_by_name['validators']._options = None
    _QUERYDELEGATORVALIDATORSRESPONSE.fields_by_name['validators']._serialized_options = b'\xc8\xde\x1f\x00'
    _QUERYDELEGATORVALIDATORREQUEST._options = None
    _QUERYDELEGATORVALIDATORREQUEST._serialized_options = b'\xe8\xa0\x1f\x00\x88\xa0\x1f\x00'
    _QUERYDELEGATORVALIDATORRESPONSE.fields_by_name['validator']._options = None
    _QUERYDELEGATORVALIDATORRESPONSE.fields_by_name['validator']._serialized_options = b'\xc8\xde\x1f\x00'
    _QUERYPOOLRESPONSE.fields_by_name['pool']._options = None
    _QUERYPOOLRESPONSE.fields_by_name['pool']._serialized_options = b'\xc8\xde\x1f\x00'
    _QUERYPARAMSRESPONSE.fields_by_name['params']._options = None
    _QUERYPARAMSRESPONSE.fields_by_name['params']._serialized_options = b'\xc8\xde\x1f\x00'
    _QUERY.methods_by_name['Validators']._options = None
    _QUERY.methods_by_name['Validators']._serialized_options = b'\x82\xd3\xe4\x93\x02$\x12"/cosmos/staking/v1beta1/validators'
    _QUERY.methods_by_name['Validator']._options = None
    _QUERY.methods_by_name['Validator']._serialized_options = b'\x82\xd3\xe4\x93\x025\x123/cosmos/staking/v1beta1/validators/{validator_addr}'
    _QUERY.methods_by_name['ValidatorDelegations']._options = None
    _QUERY.methods_by_name['ValidatorDelegations']._serialized_options = b'\x82\xd3\xe4\x93\x02A\x12?/cosmos/staking/v1beta1/validators/{validator_addr}/delegations'
    _QUERY.methods_by_name['ValidatorUnbondingDelegations']._options = None
    _QUERY.methods_by_name['ValidatorUnbondingDelegations']._serialized_options = b'\x82\xd3\xe4\x93\x02K\x12I/cosmos/staking/v1beta1/validators/{validator_addr}/unbonding_delegations'
    _QUERY.methods_by_name['Delegation']._options = None
    _QUERY.methods_by_name['Delegation']._serialized_options = b'\x82\xd3\xe4\x93\x02R\x12P/cosmos/staking/v1beta1/validators/{validator_addr}/delegations/{delegator_addr}'
    _QUERY.methods_by_name['UnbondingDelegation']._options = None
    _QUERY.methods_by_name['UnbondingDelegation']._serialized_options = b'\x82\xd3\xe4\x93\x02g\x12e/cosmos/staking/v1beta1/validators/{validator_addr}/delegations/{delegator_addr}/unbonding_delegation'
    _QUERY.methods_by_name['DelegatorDelegations']._options = None
    _QUERY.methods_by_name['DelegatorDelegations']._serialized_options = b'\x82\xd3\xe4\x93\x026\x124/cosmos/staking/v1beta1/delegations/{delegator_addr}'
    _QUERY.methods_by_name['DelegatorUnbondingDelegations']._options = None
    _QUERY.methods_by_name['DelegatorUnbondingDelegations']._serialized_options = b'\x82\xd3\xe4\x93\x02K\x12I/cosmos/staking/v1beta1/delegators/{delegator_addr}/unbonding_delegations'
    _QUERY.methods_by_name['Redelegations']._options = None
    _QUERY.methods_by_name['Redelegations']._serialized_options = b'\x82\xd3\xe4\x93\x02C\x12A/cosmos/staking/v1beta1/delegators/{delegator_addr}/redelegations'
    _QUERY.methods_by_name['DelegatorValidators']._options = None
    _QUERY.methods_by_name['DelegatorValidators']._serialized_options = b'\x82\xd3\xe4\x93\x02@\x12>/cosmos/staking/v1beta1/delegators/{delegator_addr}/validators'
    _QUERY.methods_by_name['DelegatorValidator']._options = None
    _QUERY.methods_by_name['DelegatorValidator']._serialized_options = b'\x82\xd3\xe4\x93\x02Q\x12O/cosmos/staking/v1beta1/delegators/{delegator_addr}/validators/{validator_addr}'
    _QUERY.methods_by_name['HistoricalInfo']._options = None
    _QUERY.methods_by_name['HistoricalInfo']._serialized_options = b'\x82\xd3\xe4\x93\x022\x120/cosmos/staking/v1beta1/historical_info/{height}'
    _QUERY.methods_by_name['Pool']._options = None
    _QUERY.methods_by_name['Pool']._serialized_options = b'\x82\xd3\xe4\x93\x02\x1e\x12\x1c/cosmos/staking/v1beta1/pool'
    _QUERY.methods_by_name['Params']._options = None
    _QUERY.methods_by_name['Params']._serialized_options = b'\x82\xd3\xe4\x93\x02 \x12\x1e/cosmos/staking/v1beta1/params'
    _QUERYVALIDATORSREQUEST._serialized_start = 196
    _QUERYVALIDATORSREQUEST._serialized_end = 296
    _QUERYVALIDATORSRESPONSE._serialized_start = 299
    _QUERYVALIDATORSRESPONSE._serialized_end = 446
    _QUERYVALIDATORREQUEST._serialized_start = 448
    _QUERYVALIDATORREQUEST._serialized_end = 495
    _QUERYVALIDATORRESPONSE._serialized_start = 497
    _QUERYVALIDATORRESPONSE._serialized_end = 581
    _QUERYVALIDATORDELEGATIONSREQUEST._serialized_start = 583
    _QUERYVALIDATORDELEGATIONSREQUEST._serialized_end = 701
    _QUERYVALIDATORDELEGATIONSRESPONSE._serialized_start = 704
    _QUERYVALIDATORDELEGATIONSRESPONSE._serialized_end = 903
    _QUERYVALIDATORUNBONDINGDELEGATIONSREQUEST._serialized_start = 905
    _QUERYVALIDATORUNBONDINGDELEGATIONSREQUEST._serialized_end = 1032
    _QUERYVALIDATORUNBONDINGDELEGATIONSRESPONSE._serialized_start = 1035
    _QUERYVALIDATORUNBONDINGDELEGATIONSRESPONSE._serialized_end = 1220
    _QUERYDELEGATIONREQUEST._serialized_start = 1222
    _QUERYDELEGATIONREQUEST._serialized_end = 1304
    _QUERYDELEGATIONRESPONSE._serialized_start = 1306
    _QUERYDELEGATIONRESPONSE._serialized_end = 1404
    _QUERYUNBONDINGDELEGATIONREQUEST._serialized_start = 1406
    _QUERYUNBONDINGDELEGATIONREQUEST._serialized_end = 1497
    _QUERYUNBONDINGDELEGATIONRESPONSE._serialized_start = 1499
    _QUERYUNBONDINGDELEGATIONRESPONSE._serialized_end = 1600
    _QUERYDELEGATORDELEGATIONSREQUEST._serialized_start = 1603
    _QUERYDELEGATORDELEGATIONSREQUEST._serialized_end = 1731
    _QUERYDELEGATORDELEGATIONSRESPONSE._serialized_start = 1734
    _QUERYDELEGATORDELEGATIONSRESPONSE._serialized_end = 1910
    _QUERYDELEGATORUNBONDINGDELEGATIONSREQUEST._serialized_start = 1913
    _QUERYDELEGATORUNBONDINGDELEGATIONSREQUEST._serialized_end = 2050
    _QUERYDELEGATORUNBONDINGDELEGATIONSRESPONSE._serialized_start = 2053
    _QUERYDELEGATORUNBONDINGDELEGATIONSRESPONSE._serialized_end = 2238
    _QUERYREDELEGATIONSREQUEST._serialized_start = 2241
    _QUERYREDELEGATIONSREQUEST._serialized_end = 2418
    _QUERYREDELEGATIONSRESPONSE._serialized_start = 2421
    _QUERYREDELEGATIONSRESPONSE._serialized_end = 2594
    _QUERYDELEGATORVALIDATORSREQUEST._serialized_start = 2596
    _QUERYDELEGATORVALIDATORSREQUEST._serialized_end = 2723
    _QUERYDELEGATORVALIDATORSRESPONSE._serialized_start = 2726
    _QUERYDELEGATORVALIDATORSRESPONSE._serialized_end = 2882
    _QUERYDELEGATORVALIDATORREQUEST._serialized_start = 2884
    _QUERYDELEGATORVALIDATORREQUEST._serialized_end = 2974
    _QUERYDELEGATORVALIDATORRESPONSE._serialized_start = 2976
    _QUERYDELEGATORVALIDATORRESPONSE._serialized_end = 3069
    _QUERYHISTORICALINFOREQUEST._serialized_start = 3071
    _QUERYHISTORICALINFOREQUEST._serialized_end = 3115
    _QUERYHISTORICALINFORESPONSE._serialized_start = 3117
    _QUERYHISTORICALINFORESPONSE._serialized_end = 3200
    _QUERYPOOLREQUEST._serialized_start = 3202
    _QUERYPOOLREQUEST._serialized_end = 3220
    _QUERYPOOLRESPONSE._serialized_start = 3222
    _QUERYPOOLRESPONSE._serialized_end = 3291
    _QUERYPARAMSREQUEST._serialized_start = 3293
    _QUERYPARAMSREQUEST._serialized_end = 3313
    _QUERYPARAMSRESPONSE._serialized_start = 3315
    _QUERYPARAMSRESPONSE._serialized_end = 3390
    _QUERY._serialized_start = 3393
    _QUERY._serialized_end = 6187




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n cosmos/slashing/v1beta1/tx.proto\x12\x17cosmos.slashing.v1beta1\x1a\x14gogoproto/gogo.proto"L\n\tMsgUnjail\x125\n\x0evalidator_addr\x18\x01 \x01(\tB\x1d\xf2\xde\x1f\x0eyaml:"address"\xea\xde\x1f\x07address:\x08\x88\xa0\x1f\x00\x98\xa0\x1f\x01"\x13\n\x11MsgUnjailResponse2_\n\x03Msg\x12X\n\x06Unjail\x12".cosmos.slashing.v1beta1.MsgUnjail\x1a*.cosmos.slashing.v1beta1.MsgUnjailResponseB3Z-github.com/cosmos/cosmos-sdk/x/slashing/types\xa8\xe2\x1e\x01b\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.slashing.v1beta1.tx_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z-github.com/cosmos/cosmos-sdk/x/slashing/types\xa8\xe2\x1e\x01'
    _MSGUNJAIL.fields_by_name['validator_addr']._options = None
    _MSGUNJAIL.fields_by_name['validator_addr']._serialized_options = b'\xf2\xde\x1f\x0eyaml:"address"\xea\xde\x1f\x07address'
    _MSGUNJAIL._options = None
    _MSGUNJAIL._serialized_options = b'\x88\xa0\x1f\x00\x98\xa0\x1f\x01'
    _MSGUNJAIL._serialized_start = 83
    _MSGUNJAIL._serialized_end = 159
    _MSGUNJAILRESPONSE._serialized_start = 161
    _MSGUNJAILRESPONSE._serialized_end = 180
    _MSG._serialized_start = 182
    _MSG._serialized_end = 277




from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import any_pb2 as _any_pb2
from google.protobuf import duration_pb2 as _duration_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from cosmos_proto import cosmos_pb2 as _cosmos_pb2
from cosmos.base.v1beta1 import coin_pb2 as _coin_pb2
from tendermint.types import types_pb2 as _types_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union
BOND_STATUS_BONDED: BondStatus
BOND_STATUS_UNBONDED: BondStatus
BOND_STATUS_UNBONDING: BondStatus
BOND_STATUS_UNSPECIFIED: BondStatus
DESCRIPTOR: _descriptor.FileDescriptor

class Commission(_message.Message):
    __slots__ = ['commission_rates', 'update_time']
    COMMISSION_RATES_FIELD_NUMBER: _ClassVar[int]
    UPDATE_TIME_FIELD_NUMBER: _ClassVar[int]
    commission_rates: CommissionRates
    update_time: _timestamp_pb2.Timestamp

    def __init__(self, commission_rates: _Optional[_Union[(CommissionRates, _Mapping)]]=..., update_time: _Optional[_Union[(_timestamp_pb2.Timestamp, _Mapping)]]=...) -> None:
        ...

class CommissionRates(_message.Message):
    __slots__ = ['max_change_rate', 'max_rate', 'rate']
    MAX_CHANGE_RATE_FIELD_NUMBER: _ClassVar[int]
    MAX_RATE_FIELD_NUMBER: _ClassVar[int]
    RATE_FIELD_NUMBER: _ClassVar[int]
    max_change_rate: str
    max_rate: str
    rate: str

    def __init__(self, rate: _Optional[str]=..., max_rate: _Optional[str]=..., max_change_rate: _Optional[str]=...) -> None:
        ...

class DVPair(_message.Message):
    __slots__ = ['delegator_address', 'validator_address']
    DELEGATOR_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    VALIDATOR_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    delegator_address: str
    validator_address: str

    def __init__(self, delegator_address: _Optional[str]=..., validator_address: _Optional[str]=...) -> None:
        ...

class DVPairs(_message.Message):
    __slots__ = ['pairs']
    PAIRS_FIELD_NUMBER: _ClassVar[int]
    pairs: _containers.RepeatedCompositeFieldContainer[DVPair]

    def __init__(self, pairs: _Optional[_Iterable[_Union[(DVPair, _Mapping)]]]=...) -> None:
        ...

class DVVTriplet(_message.Message):
    __slots__ = ['delegator_address', 'validator_dst_address', 'validator_src_address']
    DELEGATOR_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    VALIDATOR_DST_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    VALIDATOR_SRC_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    delegator_address: str
    validator_dst_address: str
    validator_src_address: str

    def __init__(self, delegator_address: _Optional[str]=..., validator_src_address: _Optional[str]=..., validator_dst_address: _Optional[str]=...) -> None:
        ...

class DVVTriplets(_message.Message):
    __slots__ = ['triplets']
    TRIPLETS_FIELD_NUMBER: _ClassVar[int]
    triplets: _containers.RepeatedCompositeFieldContainer[DVVTriplet]

    def __init__(self, triplets: _Optional[_Iterable[_Union[(DVVTriplet, _Mapping)]]]=...) -> None:
        ...

class Delegation(_message.Message):
    __slots__ = ['delegator_address', 'shares', 'validator_address']
    DELEGATOR_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    SHARES_FIELD_NUMBER: _ClassVar[int]
    VALIDATOR_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    delegator_address: str
    shares: str
    validator_address: str

    def __init__(self, delegator_address: _Optional[str]=..., validator_address: _Optional[str]=..., shares: _Optional[str]=...) -> None:
        ...

class DelegationResponse(_message.Message):
    __slots__ = ['balance', 'delegation']
    BALANCE_FIELD_NUMBER: _ClassVar[int]
    DELEGATION_FIELD_NUMBER: _ClassVar[int]
    balance: _coin_pb2.Coin
    delegation: Delegation

    def __init__(self, delegation: _Optional[_Union[(Delegation, _Mapping)]]=..., balance: _Optional[_Union[(_coin_pb2.Coin, _Mapping)]]=...) -> None:
        ...

class Description(_message.Message):
    __slots__ = ['details', 'identity', 'moniker', 'security_contact', 'website']
    DETAILS_FIELD_NUMBER: _ClassVar[int]
    IDENTITY_FIELD_NUMBER: _ClassVar[int]
    MONIKER_FIELD_NUMBER: _ClassVar[int]
    SECURITY_CONTACT_FIELD_NUMBER: _ClassVar[int]
    WEBSITE_FIELD_NUMBER: _ClassVar[int]
    details: str
    identity: str
    moniker: str
    security_contact: str
    website: str

    def __init__(self, moniker: _Optional[str]=..., identity: _Optional[str]=..., website: _Optional[str]=..., security_contact: _Optional[str]=..., details: _Optional[str]=...) -> None:
        ...

class HistoricalInfo(_message.Message):
    __slots__ = ['header', 'valset']
    HEADER_FIELD_NUMBER: _ClassVar[int]
    VALSET_FIELD_NUMBER: _ClassVar[int]
    header: _types_pb2.Header
    valset: _containers.RepeatedCompositeFieldContainer[Validator]

    def __init__(self, header: _Optional[_Union[(_types_pb2.Header, _Mapping)]]=..., valset: _Optional[_Iterable[_Union[(Validator, _Mapping)]]]=...) -> None:
        ...

class Params(_message.Message):
    __slots__ = ['bond_denom', 'historical_entries', 'max_entries', 'max_validators', 'unbonding_time']
    BOND_DENOM_FIELD_NUMBER: _ClassVar[int]
    HISTORICAL_ENTRIES_FIELD_NUMBER: _ClassVar[int]
    MAX_ENTRIES_FIELD_NUMBER: _ClassVar[int]
    MAX_VALIDATORS_FIELD_NUMBER: _ClassVar[int]
    UNBONDING_TIME_FIELD_NUMBER: _ClassVar[int]
    bond_denom: str
    historical_entries: int
    max_entries: int
    max_validators: int
    unbonding_time: _duration_pb2.Duration

    def __init__(self, unbonding_time: _Optional[_Union[(_duration_pb2.Duration, _Mapping)]]=..., max_validators: _Optional[int]=..., max_entries: _Optional[int]=..., historical_entries: _Optional[int]=..., bond_denom: _Optional[str]=...) -> None:
        ...

class Pool(_message.Message):
    __slots__ = ['bonded_tokens', 'not_bonded_tokens']
    BONDED_TOKENS_FIELD_NUMBER: _ClassVar[int]
    NOT_BONDED_TOKENS_FIELD_NUMBER: _ClassVar[int]
    bonded_tokens: str
    not_bonded_tokens: str

    def __init__(self, not_bonded_tokens: _Optional[str]=..., bonded_tokens: _Optional[str]=...) -> None:
        ...

class Redelegation(_message.Message):
    __slots__ = ['delegator_address', 'entries', 'validator_dst_address', 'validator_src_address']
    DELEGATOR_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    ENTRIES_FIELD_NUMBER: _ClassVar[int]
    VALIDATOR_DST_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    VALIDATOR_SRC_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    delegator_address: str
    entries: _containers.RepeatedCompositeFieldContainer[RedelegationEntry]
    validator_dst_address: str
    validator_src_address: str

    def __init__(self, delegator_address: _Optional[str]=..., validator_src_address: _Optional[str]=..., validator_dst_address: _Optional[str]=..., entries: _Optional[_Iterable[_Union[(RedelegationEntry, _Mapping)]]]=...) -> None:
        ...

class RedelegationEntry(_message.Message):
    __slots__ = ['completion_time', 'creation_height', 'initial_balance', 'shares_dst']
    COMPLETION_TIME_FIELD_NUMBER: _ClassVar[int]
    CREATION_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    INITIAL_BALANCE_FIELD_NUMBER: _ClassVar[int]
    SHARES_DST_FIELD_NUMBER: _ClassVar[int]
    completion_time: _timestamp_pb2.Timestamp
    creation_height: int
    initial_balance: str
    shares_dst: str

    def __init__(self, creation_height: _Optional[int]=..., completion_time: _Optional[_Union[(_timestamp_pb2.Timestamp, _Mapping)]]=..., initial_balance: _Optional[str]=..., shares_dst: _Optional[str]=...) -> None:
        ...

class RedelegationEntryResponse(_message.Message):
    __slots__ = ['balance', 'redelegation_entry']
    BALANCE_FIELD_NUMBER: _ClassVar[int]
    REDELEGATION_ENTRY_FIELD_NUMBER: _ClassVar[int]
    balance: str
    redelegation_entry: RedelegationEntry

    def __init__(self, redelegation_entry: _Optional[_Union[(RedelegationEntry, _Mapping)]]=..., balance: _Optional[str]=...) -> None:
        ...

class RedelegationResponse(_message.Message):
    __slots__ = ['entries', 'redelegation']
    ENTRIES_FIELD_NUMBER: _ClassVar[int]
    REDELEGATION_FIELD_NUMBER: _ClassVar[int]
    entries: _containers.RepeatedCompositeFieldContainer[RedelegationEntryResponse]
    redelegation: Redelegation

    def __init__(self, redelegation: _Optional[_Union[(Redelegation, _Mapping)]]=..., entries: _Optional[_Iterable[_Union[(RedelegationEntryResponse, _Mapping)]]]=...) -> None:
        ...

class UnbondingDelegation(_message.Message):
    __slots__ = ['delegator_address', 'entries', 'validator_address']
    DELEGATOR_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    ENTRIES_FIELD_NUMBER: _ClassVar[int]
    VALIDATOR_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    delegator_address: str
    entries: _containers.RepeatedCompositeFieldContainer[UnbondingDelegationEntry]
    validator_address: str

    def __init__(self, delegator_address: _Optional[str]=..., validator_address: _Optional[str]=..., entries: _Optional[_Iterable[_Union[(UnbondingDelegationEntry, _Mapping)]]]=...) -> None:
        ...

class UnbondingDelegationEntry(_message.Message):
    __slots__ = ['balance', 'completion_time', 'creation_height', 'initial_balance']
    BALANCE_FIELD_NUMBER: _ClassVar[int]
    COMPLETION_TIME_FIELD_NUMBER: _ClassVar[int]
    CREATION_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    INITIAL_BALANCE_FIELD_NUMBER: _ClassVar[int]
    balance: str
    completion_time: _timestamp_pb2.Timestamp
    creation_height: int
    initial_balance: str

    def __init__(self, creation_height: _Optional[int]=..., completion_time: _Optional[_Union[(_timestamp_pb2.Timestamp, _Mapping)]]=..., initial_balance: _Optional[str]=..., balance: _Optional[str]=...) -> None:
        ...

class ValAddresses(_message.Message):
    __slots__ = ['addresses']
    ADDRESSES_FIELD_NUMBER: _ClassVar[int]
    addresses: _containers.RepeatedScalarFieldContainer[str]

    def __init__(self, addresses: _Optional[_Iterable[str]]=...) -> None:
        ...

class Validator(_message.Message):
    __slots__ = ['commission', 'consensus_pubkey', 'delegator_shares', 'description', 'jailed', 'min_self_delegation', 'operator_address', 'status', 'tokens', 'unbonding_height', 'unbonding_time']
    COMMISSION_FIELD_NUMBER: _ClassVar[int]
    CONSENSUS_PUBKEY_FIELD_NUMBER: _ClassVar[int]
    DELEGATOR_SHARES_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    JAILED_FIELD_NUMBER: _ClassVar[int]
    MIN_SELF_DELEGATION_FIELD_NUMBER: _ClassVar[int]
    OPERATOR_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    TOKENS_FIELD_NUMBER: _ClassVar[int]
    UNBONDING_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    UNBONDING_TIME_FIELD_NUMBER: _ClassVar[int]
    commission: Commission
    consensus_pubkey: _any_pb2.Any
    delegator_shares: str
    description: Description
    jailed: bool
    min_self_delegation: str
    operator_address: str
    status: BondStatus
    tokens: str
    unbonding_height: int
    unbonding_time: _timestamp_pb2.Timestamp

    def __init__(self, operator_address: _Optional[str]=..., consensus_pubkey: _Optional[_Union[(_any_pb2.Any, _Mapping)]]=..., jailed: bool=..., status: _Optional[_Union[(BondStatus, str)]]=..., tokens: _Optional[str]=..., delegator_shares: _Optional[str]=..., description: _Optional[_Union[(Description, _Mapping)]]=..., unbonding_height: _Optional[int]=..., unbonding_time: _Optional[_Union[(_timestamp_pb2.Timestamp, _Mapping)]]=..., commission: _Optional[_Union[(Commission, _Mapping)]]=..., min_self_delegation: _Optional[str]=...) -> None:
        ...

class BondStatus(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []




from gogoproto import gogo_pb2 as _gogo_pb2
from cosmos.base.v1beta1 import coin_pb2 as _coin_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union
DESCRIPTOR: _descriptor.FileDescriptor

class MsgFundCommunityPool(_message.Message):
    __slots__ = ['amount', 'depositor']
    AMOUNT_FIELD_NUMBER: _ClassVar[int]
    DEPOSITOR_FIELD_NUMBER: _ClassVar[int]
    amount: _containers.RepeatedCompositeFieldContainer[_coin_pb2.Coin]
    depositor: str

    def __init__(self, amount: _Optional[_Iterable[_Union[(_coin_pb2.Coin, _Mapping)]]]=..., depositor: _Optional[str]=...) -> None:
        ...

class MsgFundCommunityPoolResponse(_message.Message):
    __slots__ = []

    def __init__(self) -> None:
        ...

class MsgSetWithdrawAddress(_message.Message):
    __slots__ = ['delegator_address', 'withdraw_address']
    DELEGATOR_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    WITHDRAW_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    delegator_address: str
    withdraw_address: str

    def __init__(self, delegator_address: _Optional[str]=..., withdraw_address: _Optional[str]=...) -> None:
        ...

class MsgSetWithdrawAddressResponse(_message.Message):
    __slots__ = []

    def __init__(self) -> None:
        ...

class MsgWithdrawDelegatorReward(_message.Message):
    __slots__ = ['delegator_address', 'validator_address']
    DELEGATOR_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    VALIDATOR_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    delegator_address: str
    validator_address: str

    def __init__(self, delegator_address: _Optional[str]=..., validator_address: _Optional[str]=...) -> None:
        ...

class MsgWithdrawDelegatorRewardResponse(_message.Message):
    __slots__ = []

    def __init__(self) -> None:
        ...

class MsgWithdrawValidatorCommission(_message.Message):
    __slots__ = ['validator_address']
    VALIDATOR_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    validator_address: str

    def __init__(self, validator_address: _Optional[str]=...) -> None:
        ...

class MsgWithdrawValidatorCommissionResponse(_message.Message):
    __slots__ = []

    def __init__(self) -> None:
        ...




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from ....cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from ....cosmos.authz.v1beta1 import authz_pb2 as cosmos_dot_authz_dot_v1beta1_dot_authz__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n cosmos/authz/v1beta1/query.proto\x12\x14cosmos.authz.v1beta1\x1a\x1cgoogle/api/annotations.proto\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a cosmos/authz/v1beta1/authz.proto"\x88\x01\n\x12QueryGrantsRequest\x12\x0f\n\x07granter\x18\x01 \x01(\t\x12\x0f\n\x07grantee\x18\x02 \x01(\t\x12\x14\n\x0cmsg_type_url\x18\x03 \x01(\t\x12:\n\npagination\x18\x04 \x01(\x0b2&.cosmos.base.query.v1beta1.PageRequest"\x7f\n\x13QueryGrantsResponse\x12+\n\x06grants\x18\x01 \x03(\x0b2\x1b.cosmos.authz.v1beta1.Grant\x12;\n\npagination\x18\x02 \x01(\x0b2\'.cosmos.base.query.v1beta1.PageResponse"h\n\x19QueryGranterGrantsRequest\x12\x0f\n\x07granter\x18\x01 \x01(\t\x12:\n\npagination\x18\x02 \x01(\x0b2&.cosmos.base.query.v1beta1.PageRequest"\x93\x01\n\x1aQueryGranterGrantsResponse\x128\n\x06grants\x18\x01 \x03(\x0b2(.cosmos.authz.v1beta1.GrantAuthorization\x12;\n\npagination\x18\x02 \x01(\x0b2\'.cosmos.base.query.v1beta1.PageResponse"h\n\x19QueryGranteeGrantsRequest\x12\x0f\n\x07grantee\x18\x01 \x01(\t\x12:\n\npagination\x18\x02 \x01(\x0b2&.cosmos.base.query.v1beta1.PageRequest"\x93\x01\n\x1aQueryGranteeGrantsResponse\x128\n\x06grants\x18\x01 \x03(\x0b2(.cosmos.authz.v1beta1.GrantAuthorization\x12;\n\npagination\x18\x02 \x01(\x0b2\'.cosmos.base.query.v1beta1.PageResponse2\xe7\x03\n\x05Query\x12\x83\x01\n\x06Grants\x12(.cosmos.authz.v1beta1.QueryGrantsRequest\x1a).cosmos.authz.v1beta1.QueryGrantsResponse"$\x82\xd3\xe4\x93\x02\x1e\x12\x1c/cosmos/authz/v1beta1/grants\x12\xaa\x01\n\rGranterGrants\x12/.cosmos.authz.v1beta1.QueryGranterGrantsRequest\x1a0.cosmos.authz.v1beta1.QueryGranterGrantsResponse"6\x82\xd3\xe4\x93\x020\x12./cosmos/authz/v1beta1/grants/granter/{granter}\x12\xaa\x01\n\rGranteeGrants\x12/.cosmos.authz.v1beta1.QueryGranteeGrantsRequest\x1a0.cosmos.authz.v1beta1.QueryGranteeGrantsResponse"6\x82\xd3\xe4\x93\x020\x12./cosmos/authz/v1beta1/grants/grantee/{grantee}B&Z$github.com/cosmos/cosmos-sdk/x/authzb\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.authz.v1beta1.query_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z$github.com/cosmos/cosmos-sdk/x/authz'
    _QUERY.methods_by_name['Grants']._options = None
    _QUERY.methods_by_name['Grants']._serialized_options = b'\x82\xd3\xe4\x93\x02\x1e\x12\x1c/cosmos/authz/v1beta1/grants'
    _QUERY.methods_by_name['GranterGrants']._options = None
    _QUERY.methods_by_name['GranterGrants']._serialized_options = b'\x82\xd3\xe4\x93\x020\x12./cosmos/authz/v1beta1/grants/granter/{granter}'
    _QUERY.methods_by_name['GranteeGrants']._options = None
    _QUERY.methods_by_name['GranteeGrants']._serialized_options = b'\x82\xd3\xe4\x93\x020\x12./cosmos/authz/v1beta1/grants/grantee/{grantee}'
    _QUERYGRANTSREQUEST._serialized_start = 167
    _QUERYGRANTSREQUEST._serialized_end = 303
    _QUERYGRANTSRESPONSE._serialized_start = 305
    _QUERYGRANTSRESPONSE._serialized_end = 432
    _QUERYGRANTERGRANTSREQUEST._serialized_start = 434
    _QUERYGRANTERGRANTSREQUEST._serialized_end = 538
    _QUERYGRANTERGRANTSRESPONSE._serialized_start = 541
    _QUERYGRANTERGRANTSRESPONSE._serialized_end = 688
    _QUERYGRANTEEGRANTSREQUEST._serialized_start = 690
    _QUERYGRANTEEGRANTSREQUEST._serialized_end = 794
    _QUERYGRANTEEGRANTSRESPONSE._serialized_start = 797
    _QUERYGRANTEEGRANTSRESPONSE._serialized_end = 944
    _QUERY._serialized_start = 947
    _QUERY._serialized_end = 1434




from gogoproto import gogo_pb2 as _gogo_pb2
from tendermint.types import types_pb2 as _types_pb2
from tendermint.types import evidence_pb2 as _evidence_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union
DESCRIPTOR: _descriptor.FileDescriptor

class Block(_message.Message):
    __slots__ = ['data', 'evidence', 'header', 'last_commit']
    DATA_FIELD_NUMBER: _ClassVar[int]
    EVIDENCE_FIELD_NUMBER: _ClassVar[int]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    LAST_COMMIT_FIELD_NUMBER: _ClassVar[int]
    data: _types_pb2.Data
    evidence: _evidence_pb2.EvidenceList
    header: _types_pb2.Header
    last_commit: _types_pb2.Commit

    def __init__(self, header: _Optional[_Union[(_types_pb2.Header, _Mapping)]]=..., data: _Optional[_Union[(_types_pb2.Data, _Mapping)]]=..., evidence: _Optional[_Union[(_evidence_pb2.EvidenceList, _Mapping)]]=..., last_commit: _Optional[_Union[(_types_pb2.Commit, _Mapping)]]=...) -> None:
        ...




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from .....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from .....ibc.core.client.v1 import client_pb2 as ibc_dot_core_dot_client_dot_v1_dot_client__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-ibc/lightclients/localhost/v1/localhost.proto\x12\x1dibc.lightclients.localhost.v1\x1a\x14gogoproto/gogo.proto\x1a\x1fibc/core/client/v1/client.proto"l\n\x0bClientState\x12%\n\x08chain_id\x18\x01 \x01(\tB\x13\xf2\xde\x1f\x0fyaml:"chain_id"\x120\n\x06height\x18\x02 \x01(\x0b2\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00:\x04\x88\xa0\x1f\x00BFZDgithub.com/cosmos/ibc-go/v3/modules/light-clients/09-localhost/typesb\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.lightclients.localhost.v1.localhost_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'ZDgithub.com/cosmos/ibc-go/v3/modules/light-clients/09-localhost/types'
    _CLIENTSTATE.fields_by_name['chain_id']._options = None
    _CLIENTSTATE.fields_by_name['chain_id']._serialized_options = b'\xf2\xde\x1f\x0fyaml:"chain_id"'
    _CLIENTSTATE.fields_by_name['height']._options = None
    _CLIENTSTATE.fields_by_name['height']._serialized_options = b'\xc8\xde\x1f\x00'
    _CLIENTSTATE._options = None
    _CLIENTSTATE._serialized_options = b'\x88\xa0\x1f\x00'
    _CLIENTSTATE._serialized_start = 135
    _CLIENTSTATE._serialized_end = 243




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ...gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1ctendermint/crypto/keys.proto\x12\x11tendermint.crypto\x1a\x14gogoproto/gogo.proto"D\n\tPublicKey\x12\x11\n\x07ed25519\x18\x01 \x01(\x0cH\x00\x12\x13\n\tsecp256k1\x18\x02 \x01(\x0cH\x00:\x08\xe8\xa1\x1f\x01\xe8\xa0\x1f\x01B\x05\n\x03sumB:Z8github.com/tendermint/tendermint/proto/tendermint/cryptob\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tendermint.crypto.keys_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z8github.com/tendermint/tendermint/proto/tendermint/crypto'
    _PUBLICKEY._options = None
    _PUBLICKEY._serialized_options = b'\xe8\xa1\x1f\x01\xe8\xa0\x1f\x01'
    _PUBLICKEY._serialized_start = 73
    _PUBLICKEY._serialized_end = 141




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from ....sentinel.session.v2 import proof_pb2 as sentinel_dot_session_dot_v2_dot_proof__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dsentinel/session/v2/msg.proto\x12\x13sentinel.session.v2\x1a\x14gogoproto/gogo.proto\x1a\x1fsentinel/session/v2/proof.proto"C\n\x0fMsgStartRequest\x12\x0b\n\x03frm\x18\x01 \x01(\t\x12\x12\n\x02id\x18\x02 \x01(\x04B\x06\xe2\xde\x1f\x02ID\x12\x0f\n\x07address\x18\x03 \x01(\t"j\n\x17MsgUpdateDetailsRequest\x12\x0b\n\x03frm\x18\x01 \x01(\t\x12/\n\x05proof\x18\x02 \x01(\x0b2\x1a.sentinel.session.v2.ProofB\x04\xc8\xde\x1f\x00\x12\x11\n\tsignature\x18\x03 \x01(\x0c"@\n\rMsgEndRequest\x12\x0b\n\x03frm\x18\x01 \x01(\t\x12\x12\n\x02id\x18\x02 \x01(\x04B\x06\xe2\xde\x1f\x02ID\x12\x0e\n\x06rating\x18\x03 \x01(\x04"\x12\n\x10MsgStartResponse"\x1a\n\x18MsgUpdateDetailsResponse"\x10\n\x0eMsgEndResponse2\xa9\x02\n\nMsgService\x12W\n\x08MsgStart\x12$.sentinel.session.v2.MsgStartRequest\x1a%.sentinel.session.v2.MsgStartResponse\x12o\n\x10MsgUpdateDetails\x12,.sentinel.session.v2.MsgUpdateDetailsRequest\x1a-.sentinel.session.v2.MsgUpdateDetailsResponse\x12Q\n\x06MsgEnd\x12".sentinel.session.v2.MsgEndRequest\x1a#.sentinel.session.v2.MsgEndResponseB:Z0github.com/sentinel-official/hub/x/session/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00b\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sentinel.session.v2.msg_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z0github.com/sentinel-official/hub/x/session/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00'
    _MSGSTARTREQUEST.fields_by_name['id']._options = None
    _MSGSTARTREQUEST.fields_by_name['id']._serialized_options = b'\xe2\xde\x1f\x02ID'
    _MSGUPDATEDETAILSREQUEST.fields_by_name['proof']._options = None
    _MSGUPDATEDETAILSREQUEST.fields_by_name['proof']._serialized_options = b'\xc8\xde\x1f\x00'
    _MSGENDREQUEST.fields_by_name['id']._options = None
    _MSGENDREQUEST.fields_by_name['id']._serialized_options = b'\xe2\xde\x1f\x02ID'
    _MSGSTARTREQUEST._serialized_start = 109
    _MSGSTARTREQUEST._serialized_end = 176
    _MSGUPDATEDETAILSREQUEST._serialized_start = 178
    _MSGUPDATEDETAILSREQUEST._serialized_end = 284
    _MSGENDREQUEST._serialized_start = 286
    _MSGENDREQUEST._serialized_end = 350
    _MSGSTARTRESPONSE._serialized_start = 352
    _MSGSTARTRESPONSE._serialized_end = 370
    _MSGUPDATEDETAILSRESPONSE._serialized_start = 372
    _MSGUPDATEDETAILSRESPONSE._serialized_end = 398
    _MSGENDRESPONSE._serialized_start = 400
    _MSGENDRESPONSE._serialized_end = 416
    _MSGSERVICE._serialized_start = 419
    _MSGSERVICE._serialized_end = 716




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from ....google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from ....cosmos.mint.v1beta1 import mint_pb2 as cosmos_dot_mint_dot_v1beta1_dot_mint__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fcosmos/mint/v1beta1/query.proto\x12\x13cosmos.mint.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1ecosmos/mint/v1beta1/mint.proto"\x14\n\x12QueryParamsRequest"H\n\x13QueryParamsResponse\x121\n\x06params\x18\x01 \x01(\x0b2\x1b.cosmos.mint.v1beta1.ParamsB\x04\xc8\xde\x1f\x00"\x17\n\x15QueryInflationRequest"[\n\x16QueryInflationResponse\x12A\n\tinflation\x18\x01 \x01(\x0cB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00"\x1e\n\x1cQueryAnnualProvisionsRequest"j\n\x1dQueryAnnualProvisionsResponse\x12I\n\x11annual_provisions\x18\x01 \x01(\x0cB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x002\xc5\x03\n\x05Query\x12\x80\x01\n\x06Params\x12\'.cosmos.mint.v1beta1.QueryParamsRequest\x1a(.cosmos.mint.v1beta1.QueryParamsResponse"#\x82\xd3\xe4\x93\x02\x1d\x12\x1b/cosmos/mint/v1beta1/params\x12\x8c\x01\n\tInflation\x12*.cosmos.mint.v1beta1.QueryInflationRequest\x1a+.cosmos.mint.v1beta1.QueryInflationResponse"&\x82\xd3\xe4\x93\x02 \x12\x1e/cosmos/mint/v1beta1/inflation\x12\xa9\x01\n\x10AnnualProvisions\x121.cosmos.mint.v1beta1.QueryAnnualProvisionsRequest\x1a2.cosmos.mint.v1beta1.QueryAnnualProvisionsResponse".\x82\xd3\xe4\x93\x02(\x12&/cosmos/mint/v1beta1/annual_provisionsB+Z)github.com/cosmos/cosmos-sdk/x/mint/typesb\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.mint.v1beta1.query_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z)github.com/cosmos/cosmos-sdk/x/mint/types'
    _QUERYPARAMSRESPONSE.fields_by_name['params']._options = None
    _QUERYPARAMSRESPONSE.fields_by_name['params']._serialized_options = b'\xc8\xde\x1f\x00'
    _QUERYINFLATIONRESPONSE.fields_by_name['inflation']._options = None
    _QUERYINFLATIONRESPONSE.fields_by_name['inflation']._serialized_options = b'\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00'
    _QUERYANNUALPROVISIONSRESPONSE.fields_by_name['annual_provisions']._options = None
    _QUERYANNUALPROVISIONSRESPONSE.fields_by_name['annual_provisions']._serialized_options = b'\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00'
    _QUERY.methods_by_name['Params']._options = None
    _QUERY.methods_by_name['Params']._serialized_options = b'\x82\xd3\xe4\x93\x02\x1d\x12\x1b/cosmos/mint/v1beta1/params'
    _QUERY.methods_by_name['Inflation']._options = None
    _QUERY.methods_by_name['Inflation']._serialized_options = b'\x82\xd3\xe4\x93\x02 \x12\x1e/cosmos/mint/v1beta1/inflation'
    _QUERY.methods_by_name['AnnualProvisions']._options = None
    _QUERY.methods_by_name['AnnualProvisions']._serialized_options = b'\x82\xd3\xe4\x93\x02(\x12&/cosmos/mint/v1beta1/annual_provisions'
    _QUERYPARAMSREQUEST._serialized_start = 140
    _QUERYPARAMSREQUEST._serialized_end = 160
    _QUERYPARAMSRESPONSE._serialized_start = 162
    _QUERYPARAMSRESPONSE._serialized_end = 234
    _QUERYINFLATIONREQUEST._serialized_start = 236
    _QUERYINFLATIONREQUEST._serialized_end = 259
    _QUERYINFLATIONRESPONSE._serialized_start = 261
    _QUERYINFLATIONRESPONSE._serialized_end = 352
    _QUERYANNUALPROVISIONSREQUEST._serialized_start = 354
    _QUERYANNUALPROVISIONSREQUEST._serialized_end = 384
    _QUERYANNUALPROVISIONSRESPONSE._serialized_start = 386
    _QUERYANNUALPROVISIONSRESPONSE._serialized_end = 492
    _QUERY._serialized_start = 495
    _QUERY._serialized_end = 948



from . import deposit
from . import mint
from . import node
from . import plan
from . import provider
from . import session
from . import subscription
from . import swap
from . import types
from . import vpn




from gogoproto import gogo_pb2 as _gogo_pb2
from cosmos.base.v1beta1 import coin_pb2 as _coin_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union
DESCRIPTOR: _descriptor.FileDescriptor

class GenesisState(_message.Message):
    __slots__ = ['constant_fee']
    CONSTANT_FEE_FIELD_NUMBER: _ClassVar[int]
    constant_fee: _coin_pb2.Coin

    def __init__(self, constant_fee: _Optional[_Union[(_coin_pb2.Coin, _Mapping)]]=...) -> None:
        ...




from cosmos.base.v1beta1 import coin_pb2 as _coin_pb2
from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union
DESCRIPTOR: _descriptor.FileDescriptor

class Swap(_message.Message):
    __slots__ = ['amount', 'receiver', 'tx_hash']
    AMOUNT_FIELD_NUMBER: _ClassVar[int]
    RECEIVER_FIELD_NUMBER: _ClassVar[int]
    TX_HASH_FIELD_NUMBER: _ClassVar[int]
    amount: _coin_pb2.Coin
    receiver: str
    tx_hash: bytes

    def __init__(self, tx_hash: _Optional[bytes]=..., receiver: _Optional[str]=..., amount: _Optional[_Union[(_coin_pb2.Coin, _Mapping)]]=...) -> None:
        ...




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&cosmos/evidence/v1beta1/evidence.proto\x12\x17cosmos.evidence.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1fgoogle/protobuf/timestamp.proto"\xa8\x01\n\x0cEquivocation\x12\x0e\n\x06height\x18\x01 \x01(\x03\x122\n\x04time\x18\x02 \x01(\x0b2\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01\x12\r\n\x05power\x18\x03 \x01(\x03\x127\n\x11consensus_address\x18\x04 \x01(\tB\x1c\xf2\xde\x1f\x18yaml:"consensus_address":\x0c\x98\xa0\x1f\x00\x88\xa0\x1f\x00\xe8\xa0\x1f\x00B3Z-github.com/cosmos/cosmos-sdk/x/evidence/types\xa8\xe2\x1e\x01b\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.evidence.v1beta1.evidence_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z-github.com/cosmos/cosmos-sdk/x/evidence/types\xa8\xe2\x1e\x01'
    _EQUIVOCATION.fields_by_name['time']._options = None
    _EQUIVOCATION.fields_by_name['time']._serialized_options = b'\xc8\xde\x1f\x00\x90\xdf\x1f\x01'
    _EQUIVOCATION.fields_by_name['consensus_address']._options = None
    _EQUIVOCATION.fields_by_name['consensus_address']._serialized_options = b'\xf2\xde\x1f\x18yaml:"consensus_address"'
    _EQUIVOCATION._options = None
    _EQUIVOCATION._serialized_options = b'\x98\xa0\x1f\x00\x88\xa0\x1f\x00\xe8\xa0\x1f\x00'
    _EQUIVOCATION._serialized_start = 123
    _EQUIVOCATION._serialized_end = 291




from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import any_pb2 as _any_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union
DESCRIPTOR: _descriptor.FileDescriptor

class MsgCreateClient(_message.Message):
    __slots__ = ['client_state', 'consensus_state', 'signer']
    CLIENT_STATE_FIELD_NUMBER: _ClassVar[int]
    CONSENSUS_STATE_FIELD_NUMBER: _ClassVar[int]
    SIGNER_FIELD_NUMBER: _ClassVar[int]
    client_state: _any_pb2.Any
    consensus_state: _any_pb2.Any
    signer: str

    def __init__(self, client_state: _Optional[_Union[(_any_pb2.Any, _Mapping)]]=..., consensus_state: _Optional[_Union[(_any_pb2.Any, _Mapping)]]=..., signer: _Optional[str]=...) -> None:
        ...

class MsgCreateClientResponse(_message.Message):
    __slots__ = []

    def __init__(self) -> None:
        ...

class MsgSubmitMisbehaviour(_message.Message):
    __slots__ = ['client_id', 'misbehaviour', 'signer']
    CLIENT_ID_FIELD_NUMBER: _ClassVar[int]
    MISBEHAVIOUR_FIELD_NUMBER: _ClassVar[int]
    SIGNER_FIELD_NUMBER: _ClassVar[int]
    client_id: str
    misbehaviour: _any_pb2.Any
    signer: str

    def __init__(self, client_id: _Optional[str]=..., misbehaviour: _Optional[_Union[(_any_pb2.Any, _Mapping)]]=..., signer: _Optional[str]=...) -> None:
        ...

class MsgSubmitMisbehaviourResponse(_message.Message):
    __slots__ = []

    def __init__(self) -> None:
        ...

class MsgUpdateClient(_message.Message):
    __slots__ = ['client_id', 'header', 'signer']
    CLIENT_ID_FIELD_NUMBER: _ClassVar[int]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    SIGNER_FIELD_NUMBER: _ClassVar[int]
    client_id: str
    header: _any_pb2.Any
    signer: str

    def __init__(self, client_id: _Optional[str]=..., header: _Optional[_Union[(_any_pb2.Any, _Mapping)]]=..., signer: _Optional[str]=...) -> None:
        ...

class MsgUpdateClientResponse(_message.Message):
    __slots__ = []

    def __init__(self) -> None:
        ...

class MsgUpgradeClient(_message.Message):
    __slots__ = ['client_id', 'client_state', 'consensus_state', 'proof_upgrade_client', 'proof_upgrade_consensus_state', 'signer']
    CLIENT_ID_FIELD_NUMBER: _ClassVar[int]
    CLIENT_STATE_FIELD_NUMBER: _ClassVar[int]
    CONSENSUS_STATE_FIELD_NUMBER: _ClassVar[int]
    PROOF_UPGRADE_CLIENT_FIELD_NUMBER: _ClassVar[int]
    PROOF_UPGRADE_CONSENSUS_STATE_FIELD_NUMBER: _ClassVar[int]
    SIGNER_FIELD_NUMBER: _ClassVar[int]
    client_id: str
    client_state: _any_pb2.Any
    consensus_state: _any_pb2.Any
    proof_upgrade_client: bytes
    proof_upgrade_consensus_state: bytes
    signer: str

    def __init__(self, client_id: _Optional[str]=..., client_state: _Optional[_Union[(_any_pb2.Any, _Mapping)]]=..., consensus_state: _Optional[_Union[(_any_pb2.Any, _Mapping)]]=..., proof_upgrade_client: _Optional[bytes]=..., proof_upgrade_consensus_state: _Optional[bytes]=..., signer: _Optional[str]=...) -> None:
        ...

class MsgUpgradeClientResponse(_message.Message):
    __slots__ = []

    def __init__(self) -> None:
        ...




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from .....cosmos.crypto.multisig.v1beta1 import multisig_pb2 as cosmos_dot_crypto_dot_multisig_dot_v1beta1_dot_multisig__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'cosmos/tx/signing/v1beta1/signing.proto\x12\x19cosmos.tx.signing.v1beta1\x1a-cosmos/crypto/multisig/v1beta1/multisig.proto\x1a\x19google/protobuf/any.proto"Z\n\x14SignatureDescriptors\x12B\n\nsignatures\x18\x01 \x03(\x0b2..cosmos.tx.signing.v1beta1.SignatureDescriptor"\xa4\x04\n\x13SignatureDescriptor\x12(\n\npublic_key\x18\x01 \x01(\x0b2\x14.google.protobuf.Any\x12A\n\x04data\x18\x02 \x01(\x0b23.cosmos.tx.signing.v1beta1.SignatureDescriptor.Data\x12\x10\n\x08sequence\x18\x03 \x01(\x04\x1a\x8d\x03\n\x04Data\x12L\n\x06single\x18\x01 \x01(\x0b2:.cosmos.tx.signing.v1beta1.SignatureDescriptor.Data.SingleH\x00\x12J\n\x05multi\x18\x02 \x01(\x0b29.cosmos.tx.signing.v1beta1.SignatureDescriptor.Data.MultiH\x00\x1aN\n\x06Single\x121\n\x04mode\x18\x01 \x01(\x0e2#.cosmos.tx.signing.v1beta1.SignMode\x12\x11\n\tsignature\x18\x02 \x01(\x0c\x1a\x93\x01\n\x05Multi\x12A\n\x08bitarray\x18\x01 \x01(\x0b2/.cosmos.crypto.multisig.v1beta1.CompactBitArray\x12G\n\nsignatures\x18\x02 \x03(\x0b23.cosmos.tx.signing.v1beta1.SignatureDescriptor.DataB\x05\n\x03sum*\x8b\x01\n\x08SignMode\x12\x19\n\x15SIGN_MODE_UNSPECIFIED\x10\x00\x12\x14\n\x10SIGN_MODE_DIRECT\x10\x01\x12\x15\n\x11SIGN_MODE_TEXTUAL\x10\x02\x12\x1f\n\x1bSIGN_MODE_LEGACY_AMINO_JSON\x10\x7f\x12\x16\n\x11SIGN_MODE_EIP_191\x10\xbf\x01B/Z-github.com/cosmos/cosmos-sdk/types/tx/signingb\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.tx.signing.v1beta1.signing_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z-github.com/cosmos/cosmos-sdk/types/tx/signing'
    _SIGNMODE._serialized_start = 788
    _SIGNMODE._serialized_end = 927
    _SIGNATUREDESCRIPTORS._serialized_start = 144
    _SIGNATUREDESCRIPTORS._serialized_end = 234
    _SIGNATUREDESCRIPTOR._serialized_start = 237
    _SIGNATUREDESCRIPTOR._serialized_end = 785
    _SIGNATUREDESCRIPTOR_DATA._serialized_start = 388
    _SIGNATUREDESCRIPTOR_DATA._serialized_end = 785
    _SIGNATUREDESCRIPTOR_DATA_SINGLE._serialized_start = 550
    _SIGNATUREDESCRIPTOR_DATA_SINGLE._serialized_end = 628
    _SIGNATUREDESCRIPTOR_DATA_MULTI._serialized_start = 631
    _SIGNATUREDESCRIPTOR_DATA_MULTI._serialized_end = 778




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from ....google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from ....cosmos.params.v1beta1 import params_pb2 as cosmos_dot_params_dot_v1beta1_dot_params__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!cosmos/params/v1beta1/query.proto\x12\x15cosmos.params.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a"cosmos/params/v1beta1/params.proto"3\n\x12QueryParamsRequest\x12\x10\n\x08subspace\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t"N\n\x13QueryParamsResponse\x127\n\x05param\x18\x01 \x01(\x0b2".cosmos.params.v1beta1.ParamChangeB\x04\xc8\xde\x1f\x002\x90\x01\n\x05Query\x12\x86\x01\n\x06Params\x12).cosmos.params.v1beta1.QueryParamsRequest\x1a*.cosmos.params.v1beta1.QueryParamsResponse"%\x82\xd3\xe4\x93\x02\x1f\x12\x1d/cosmos/params/v1beta1/paramsB6Z4github.com/cosmos/cosmos-sdk/x/params/types/proposalb\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.params.v1beta1.query_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z4github.com/cosmos/cosmos-sdk/x/params/types/proposal'
    _QUERYPARAMSRESPONSE.fields_by_name['param']._options = None
    _QUERYPARAMSRESPONSE.fields_by_name['param']._serialized_options = b'\xc8\xde\x1f\x00'
    _QUERY.methods_by_name['Params']._options = None
    _QUERY.methods_by_name['Params']._serialized_options = b'\x82\xd3\xe4\x93\x02\x1f\x12\x1d/cosmos/params/v1beta1/params'
    _QUERYPARAMSREQUEST._serialized_start = 148
    _QUERYPARAMSREQUEST._serialized_end = 199
    _QUERYPARAMSRESPONSE._serialized_start = 201
    _QUERYPARAMSRESPONSE._serialized_end = 279
    _QUERY._serialized_start = 282
    _QUERY._serialized_end = 426




from cosmos.base.v1beta1 import coin_pb2 as _coin_pb2
from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import duration_pb2 as _duration_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union
DESCRIPTOR: _descriptor.FileDescriptor

class Params(_message.Message):
    __slots__ = ['active_duration', 'deposit', 'max_gigabyte_prices', 'max_hourly_prices', 'max_subscription_gigabytes', 'max_subscription_hours', 'min_gigabyte_prices', 'min_hourly_prices', 'min_subscription_gigabytes', 'min_subscription_hours', 'staking_share']
    ACTIVE_DURATION_FIELD_NUMBER: _ClassVar[int]
    DEPOSIT_FIELD_NUMBER: _ClassVar[int]
    MAX_GIGABYTE_PRICES_FIELD_NUMBER: _ClassVar[int]
    MAX_HOURLY_PRICES_FIELD_NUMBER: _ClassVar[int]
    MAX_SUBSCRIPTION_GIGABYTES_FIELD_NUMBER: _ClassVar[int]
    MAX_SUBSCRIPTION_HOURS_FIELD_NUMBER: _ClassVar[int]
    MIN_GIGABYTE_PRICES_FIELD_NUMBER: _ClassVar[int]
    MIN_HOURLY_PRICES_FIELD_NUMBER: _ClassVar[int]
    MIN_SUBSCRIPTION_GIGABYTES_FIELD_NUMBER: _ClassVar[int]
    MIN_SUBSCRIPTION_HOURS_FIELD_NUMBER: _ClassVar[int]
    STAKING_SHARE_FIELD_NUMBER: _ClassVar[int]
    active_duration: _duration_pb2.Duration
    deposit: _coin_pb2.Coin
    max_gigabyte_prices: _containers.RepeatedCompositeFieldContainer[_coin_pb2.Coin]
    max_hourly_prices: _containers.RepeatedCompositeFieldContainer[_coin_pb2.Coin]
    max_subscription_gigabytes: int
    max_subscription_hours: int
    min_gigabyte_prices: _containers.RepeatedCompositeFieldContainer[_coin_pb2.Coin]
    min_hourly_prices: _containers.RepeatedCompositeFieldContainer[_coin_pb2.Coin]
    min_subscription_gigabytes: int
    min_subscription_hours: int
    staking_share: str

    def __init__(self, deposit: _Optional[_Union[(_coin_pb2.Coin, _Mapping)]]=..., active_duration: _Optional[_Union[(_duration_pb2.Duration, _Mapping)]]=..., max_gigabyte_prices: _Optional[_Iterable[_Union[(_coin_pb2.Coin, _Mapping)]]]=..., min_gigabyte_prices: _Optional[_Iterable[_Union[(_coin_pb2.Coin, _Mapping)]]]=..., max_hourly_prices: _Optional[_Iterable[_Union[(_coin_pb2.Coin, _Mapping)]]]=..., min_hourly_prices: _Optional[_Iterable[_Union[(_coin_pb2.Coin, _Mapping)]]]=..., max_subscription_gigabytes: _Optional[int]=..., min_subscription_gigabytes: _Optional[int]=..., max_subscription_hours: _Optional[int]=..., min_subscription_hours: _Optional[int]=..., staking_share: _Optional[str]=...) -> None:
        ...




from cosmos.base.v1beta1 import coin_pb2 as _coin_pb2
from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import duration_pb2 as _duration_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from sentinel.types.v1 import status_pb2 as _status_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union
DESCRIPTOR: _descriptor.FileDescriptor

class Plan(_message.Message):
    __slots__ = ['bytes', 'id', 'price', 'provider', 'status', 'status_at', 'validity']
    BYTES_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    PRICE_FIELD_NUMBER: _ClassVar[int]
    PROVIDER_FIELD_NUMBER: _ClassVar[int]
    STATUS_AT_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    VALIDITY_FIELD_NUMBER: _ClassVar[int]
    bytes: str
    id: int
    price: _containers.RepeatedCompositeFieldContainer[_coin_pb2.Coin]
    provider: str
    status: _status_pb2.Status
    status_at: _timestamp_pb2.Timestamp
    validity: _duration_pb2.Duration

    def __init__(self, id: _Optional[int]=..., provider: _Optional[str]=..., price: _Optional[_Iterable[_Union[(_coin_pb2.Coin, _Mapping)]]]=..., validity: _Optional[_Union[(_duration_pb2.Duration, _Mapping)]]=..., bytes: _Optional[str]=..., status: _Optional[_Union[(_status_pb2.Status, str)]]=..., status_at: _Optional[_Union[(_timestamp_pb2.Timestamp, _Mapping)]]=...) -> None:
        ...




from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union
DESCRIPTOR: _descriptor.FileDescriptor

class Pair(_message.Message):
    __slots__ = ['key', 'value']
    KEY_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    key: bytes
    value: bytes

    def __init__(self, key: _Optional[bytes]=..., value: _Optional[bytes]=...) -> None:
        ...

class Pairs(_message.Message):
    __slots__ = ['pairs']
    PAIRS_FIELD_NUMBER: _ClassVar[int]
    pairs: _containers.RepeatedCompositeFieldContainer[Pair]

    def __init__(self, pairs: _Optional[_Iterable[_Union[(Pair, _Mapping)]]]=...) -> None:
        ...




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from .....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from .....tendermint.abci import types_pb2 as tendermint_dot_abci_dot_types__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#cosmos/base/abci/v1beta1/abci.proto\x12\x18cosmos.base.abci.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1btendermint/abci/types.proto\x1a\x19google/protobuf/any.proto"\xe6\x02\n\nTxResponse\x12\x0e\n\x06height\x18\x01 \x01(\x03\x12\x1a\n\x06txhash\x18\x02 \x01(\tB\n\xe2\xde\x1f\x06TxHash\x12\x11\n\tcodespace\x18\x03 \x01(\t\x12\x0c\n\x04code\x18\x04 \x01(\r\x12\x0c\n\x04data\x18\x05 \x01(\t\x12\x0f\n\x07raw_log\x18\x06 \x01(\t\x12O\n\x04logs\x18\x07 \x03(\x0b2(.cosmos.base.abci.v1beta1.ABCIMessageLogB\x17\xaa\xdf\x1f\x0fABCIMessageLogs\xc8\xde\x1f\x00\x12\x0c\n\x04info\x18\x08 \x01(\t\x12\x12\n\ngas_wanted\x18\t \x01(\x03\x12\x10\n\x08gas_used\x18\n \x01(\x03\x12 \n\x02tx\x18\x0b \x01(\x0b2\x14.google.protobuf.Any\x12\x11\n\ttimestamp\x18\x0c \x01(\t\x12,\n\x06events\x18\r \x03(\x0b2\x16.tendermint.abci.EventB\x04\xc8\xde\x1f\x00:\x04\x88\xa0\x1f\x00"\x83\x01\n\x0eABCIMessageLog\x12\x11\n\tmsg_index\x18\x01 \x01(\r\x12\x0b\n\x03log\x18\x02 \x01(\t\x12K\n\x06events\x18\x03 \x03(\x0b2%.cosmos.base.abci.v1beta1.StringEventB\x14\xaa\xdf\x1f\x0cStringEvents\xc8\xde\x1f\x00:\x04\x80\xdc \x01"`\n\x0bStringEvent\x12\x0c\n\x04type\x18\x01 \x01(\t\x12=\n\nattributes\x18\x02 \x03(\x0b2#.cosmos.base.abci.v1beta1.AttributeB\x04\xc8\xde\x1f\x00:\x04\x80\xdc \x01"\'\n\tAttribute\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t"[\n\x07GasInfo\x12)\n\ngas_wanted\x18\x01 \x01(\x04B\x15\xf2\xde\x1f\x11yaml:"gas_wanted"\x12%\n\x08gas_used\x18\x02 \x01(\x04B\x13\xf2\xde\x1f\x0fyaml:"gas_used""W\n\x06Result\x12\x0c\n\x04data\x18\x01 \x01(\x0c\x12\x0b\n\x03log\x18\x02 \x01(\t\x12,\n\x06events\x18\x03 \x03(\x0b2\x16.tendermint.abci.EventB\x04\xc8\xde\x1f\x00:\x04\x88\xa0\x1f\x00"\x85\x01\n\x12SimulationResponse\x12=\n\x08gas_info\x18\x01 \x01(\x0b2!.cosmos.base.abci.v1beta1.GasInfoB\x08\xd0\xde\x1f\x01\xc8\xde\x1f\x00\x120\n\x06result\x18\x02 \x01(\x0b2 .cosmos.base.abci.v1beta1.Result"/\n\x07MsgData\x12\x10\n\x08msg_type\x18\x01 \x01(\t\x12\x0c\n\x04data\x18\x02 \x01(\x0c:\x04\x80\xdc \x01"B\n\tTxMsgData\x12/\n\x04data\x18\x01 \x03(\x0b2!.cosmos.base.abci.v1beta1.MsgData:\x04\x80\xdc \x01"\x99\x02\n\x0fSearchTxsResult\x12:\n\x0btotal_count\x18\x01 \x01(\x04B%\xf2\xde\x1f\x12yaml:"total_count"\xea\xde\x1f\x0btotal_count\x12\r\n\x05count\x18\x02 \x01(\x04\x12:\n\x0bpage_number\x18\x03 \x01(\x04B%\xf2\xde\x1f\x12yaml:"page_number"\xea\xde\x1f\x0bpage_number\x127\n\npage_total\x18\x04 \x01(\x04B#\xf2\xde\x1f\x11yaml:"page_total"\xea\xde\x1f\npage_total\x12\r\n\x05limit\x18\x05 \x01(\x04\x121\n\x03txs\x18\x06 \x03(\x0b2$.cosmos.base.abci.v1beta1.TxResponse:\x04\x80\xdc \x01B(Z"github.com/cosmos/cosmos-sdk/types\xd8\xe1\x1e\x00b\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.base.abci.v1beta1.abci_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z"github.com/cosmos/cosmos-sdk/types\xd8\xe1\x1e\x00'
    _TXRESPONSE.fields_by_name['txhash']._options = None
    _TXRESPONSE.fields_by_name['txhash']._serialized_options = b'\xe2\xde\x1f\x06TxHash'
    _TXRESPONSE.fields_by_name['logs']._options = None
    _TXRESPONSE.fields_by_name['logs']._serialized_options = b'\xaa\xdf\x1f\x0fABCIMessageLogs\xc8\xde\x1f\x00'
    _TXRESPONSE.fields_by_name['events']._options = None
    _TXRESPONSE.fields_by_name['events']._serialized_options = b'\xc8\xde\x1f\x00'
    _TXRESPONSE._options = None
    _TXRESPONSE._serialized_options = b'\x88\xa0\x1f\x00'
    _ABCIMESSAGELOG.fields_by_name['events']._options = None
    _ABCIMESSAGELOG.fields_by_name['events']._serialized_options = b'\xaa\xdf\x1f\x0cStringEvents\xc8\xde\x1f\x00'
    _ABCIMESSAGELOG._options = None
    _ABCIMESSAGELOG._serialized_options = b'\x80\xdc \x01'
    _STRINGEVENT.fields_by_name['attributes']._options = None
    _STRINGEVENT.fields_by_name['attributes']._serialized_options = b'\xc8\xde\x1f\x00'
    _STRINGEVENT._options = None
    _STRINGEVENT._serialized_options = b'\x80\xdc \x01'
    _GASINFO.fields_by_name['gas_wanted']._options = None
    _GASINFO.fields_by_name['gas_wanted']._serialized_options = b'\xf2\xde\x1f\x11yaml:"gas_wanted"'
    _GASINFO.fields_by_name['gas_used']._options = None
    _GASINFO.fields_by_name['gas_used']._serialized_options = b'\xf2\xde\x1f\x0fyaml:"gas_used"'
    _RESULT.fields_by_name['events']._options = None
    _RESULT.fields_by_name['events']._serialized_options = b'\xc8\xde\x1f\x00'
    _RESULT._options = None
    _RESULT._serialized_options = b'\x88\xa0\x1f\x00'
    _SIMULATIONRESPONSE.fields_by_name['gas_info']._options = None
    _SIMULATIONRESPONSE.fields_by_name['gas_info']._serialized_options = b'\xd0\xde\x1f\x01\xc8\xde\x1f\x00'
    _MSGDATA._options = None
    _MSGDATA._serialized_options = b'\x80\xdc \x01'
    _TXMSGDATA._options = None
    _TXMSGDATA._serialized_options = b'\x80\xdc \x01'
    _SEARCHTXSRESULT.fields_by_name['total_count']._options = None
    _SEARCHTXSRESULT.fields_by_name['total_count']._serialized_options = b'\xf2\xde\x1f\x12yaml:"total_count"\xea\xde\x1f\x0btotal_count'
    _SEARCHTXSRESULT.fields_by_name['page_number']._options = None
    _SEARCHTXSRESULT.fields_by_name['page_number']._serialized_options = b'\xf2\xde\x1f\x12yaml:"page_number"\xea\xde\x1f\x0bpage_number'
    _SEARCHTXSRESULT.fields_by_name['page_total']._options = None
    _SEARCHTXSRESULT.fields_by_name['page_total']._serialized_options = b'\xf2\xde\x1f\x11yaml:"page_total"\xea\xde\x1f\npage_total'
    _SEARCHTXSRESULT._options = None
    _SEARCHTXSRESULT._serialized_options = b'\x80\xdc \x01'
    _TXRESPONSE._serialized_start = 144
    _TXRESPONSE._serialized_end = 502
    _ABCIMESSAGELOG._serialized_start = 505
    _ABCIMESSAGELOG._serialized_end = 636
    _STRINGEVENT._serialized_start = 638
    _STRINGEVENT._serialized_end = 734
    _ATTRIBUTE._serialized_start = 736
    _ATTRIBUTE._serialized_end = 775
    _GASINFO._serialized_start = 777
    _GASINFO._serialized_end = 868
    _RESULT._serialized_start = 870
    _RESULT._serialized_end = 957
    _SIMULATIONRESPONSE._serialized_start = 960
    _SIMULATIONRESPONSE._serialized_end = 1093
    _MSGDATA._serialized_start = 1095
    _MSGDATA._serialized_end = 1142
    _TXMSGDATA._serialized_start = 1144
    _TXMSGDATA._serialized_end = 1210
    _SEARCHTXSRESULT._serialized_start = 1213
    _SEARCHTXSRESULT._serialized_end = 1494




from gogoproto import gogo_pb2 as _gogo_pb2
from cosmos.base.v1beta1 import coin_pb2 as _coin_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union
DESCRIPTOR: _descriptor.FileDescriptor

class CommunityPoolSpendProposal(_message.Message):
    __slots__ = ['amount', 'description', 'recipient', 'title']
    AMOUNT_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    RECIPIENT_FIELD_NUMBER: _ClassVar[int]
    TITLE_FIELD_NUMBER: _ClassVar[int]
    amount: _containers.RepeatedCompositeFieldContainer[_coin_pb2.Coin]
    description: str
    recipient: str
    title: str

    def __init__(self, title: _Optional[str]=..., description: _Optional[str]=..., recipient: _Optional[str]=..., amount: _Optional[_Iterable[_Union[(_coin_pb2.Coin, _Mapping)]]]=...) -> None:
        ...

class CommunityPoolSpendProposalWithDeposit(_message.Message):
    __slots__ = ['amount', 'deposit', 'description', 'recipient', 'title']
    AMOUNT_FIELD_NUMBER: _ClassVar[int]
    DEPOSIT_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    RECIPIENT_FIELD_NUMBER: _ClassVar[int]
    TITLE_FIELD_NUMBER: _ClassVar[int]
    amount: str
    deposit: str
    description: str
    recipient: str
    title: str

    def __init__(self, title: _Optional[str]=..., description: _Optional[str]=..., recipient: _Optional[str]=..., amount: _Optional[str]=..., deposit: _Optional[str]=...) -> None:
        ...

class DelegationDelegatorReward(_message.Message):
    __slots__ = ['reward', 'validator_address']
    REWARD_FIELD_NUMBER: _ClassVar[int]
    VALIDATOR_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    reward: _containers.RepeatedCompositeFieldContainer[_coin_pb2.DecCoin]
    validator_address: str

    def __init__(self, validator_address: _Optional[str]=..., reward: _Optional[_Iterable[_Union[(_coin_pb2.DecCoin, _Mapping)]]]=...) -> None:
        ...

class DelegatorStartingInfo(_message.Message):
    __slots__ = ['height', 'previous_period', 'stake']
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    PREVIOUS_PERIOD_FIELD_NUMBER: _ClassVar[int]
    STAKE_FIELD_NUMBER: _ClassVar[int]
    height: int
    previous_period: int
    stake: str

    def __init__(self, previous_period: _Optional[int]=..., stake: _Optional[str]=..., height: _Optional[int]=...) -> None:
        ...

class FeePool(_message.Message):
    __slots__ = ['community_pool']
    COMMUNITY_POOL_FIELD_NUMBER: _ClassVar[int]
    community_pool: _containers.RepeatedCompositeFieldContainer[_coin_pb2.DecCoin]

    def __init__(self, community_pool: _Optional[_Iterable[_Union[(_coin_pb2.DecCoin, _Mapping)]]]=...) -> None:
        ...

class Params(_message.Message):
    __slots__ = ['base_proposer_reward', 'bonus_proposer_reward', 'community_tax', 'withdraw_addr_enabled']
    BASE_PROPOSER_REWARD_FIELD_NUMBER: _ClassVar[int]
    BONUS_PROPOSER_REWARD_FIELD_NUMBER: _ClassVar[int]
    COMMUNITY_TAX_FIELD_NUMBER: _ClassVar[int]
    WITHDRAW_ADDR_ENABLED_FIELD_NUMBER: _ClassVar[int]
    base_proposer_reward: str
    bonus_proposer_reward: str
    community_tax: str
    withdraw_addr_enabled: bool

    def __init__(self, community_tax: _Optional[str]=..., base_proposer_reward: _Optional[str]=..., bonus_proposer_reward: _Optional[str]=..., withdraw_addr_enabled: bool=...) -> None:
        ...

class ValidatorAccumulatedCommission(_message.Message):
    __slots__ = ['commission']
    COMMISSION_FIELD_NUMBER: _ClassVar[int]
    commission: _containers.RepeatedCompositeFieldContainer[_coin_pb2.DecCoin]

    def __init__(self, commission: _Optional[_Iterable[_Union[(_coin_pb2.DecCoin, _Mapping)]]]=...) -> None:
        ...

class ValidatorCurrentRewards(_message.Message):
    __slots__ = ['period', 'rewards']
    PERIOD_FIELD_NUMBER: _ClassVar[int]
    REWARDS_FIELD_NUMBER: _ClassVar[int]
    period: int
    rewards: _containers.RepeatedCompositeFieldContainer[_coin_pb2.DecCoin]

    def __init__(self, rewards: _Optional[_Iterable[_Union[(_coin_pb2.DecCoin, _Mapping)]]]=..., period: _Optional[int]=...) -> None:
        ...

class ValidatorHistoricalRewards(_message.Message):
    __slots__ = ['cumulative_reward_ratio', 'reference_count']
    CUMULATIVE_REWARD_RATIO_FIELD_NUMBER: _ClassVar[int]
    REFERENCE_COUNT_FIELD_NUMBER: _ClassVar[int]
    cumulative_reward_ratio: _containers.RepeatedCompositeFieldContainer[_coin_pb2.DecCoin]
    reference_count: int

    def __init__(self, cumulative_reward_ratio: _Optional[_Iterable[_Union[(_coin_pb2.DecCoin, _Mapping)]]]=..., reference_count: _Optional[int]=...) -> None:
        ...

class ValidatorOutstandingRewards(_message.Message):
    __slots__ = ['rewards']
    REWARDS_FIELD_NUMBER: _ClassVar[int]
    rewards: _containers.RepeatedCompositeFieldContainer[_coin_pb2.DecCoin]

    def __init__(self, rewards: _Optional[_Iterable[_Union[(_coin_pb2.DecCoin, _Mapping)]]]=...) -> None:
        ...

class ValidatorSlashEvent(_message.Message):
    __slots__ = ['fraction', 'validator_period']
    FRACTION_FIELD_NUMBER: _ClassVar[int]
    VALIDATOR_PERIOD_FIELD_NUMBER: _ClassVar[int]
    fraction: str
    validator_period: int

    def __init__(self, validator_period: _Optional[int]=..., fraction: _Optional[str]=...) -> None:
        ...

class ValidatorSlashEvents(_message.Message):
    __slots__ = ['validator_slash_events']
    VALIDATOR_SLASH_EVENTS_FIELD_NUMBER: _ClassVar[int]
    validator_slash_events: _containers.RepeatedCompositeFieldContainer[ValidatorSlashEvent]

    def __init__(self, validator_slash_events: _Optional[_Iterable[_Union[(ValidatorSlashEvent, _Mapping)]]]=...) -> None:
        ...




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from ....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from ....google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from ....sentinel.deposit.v1 import deposit_pb2 as sentinel_dot_deposit_dot_v1_dot_deposit__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!sentinel/deposit/v1/querier.proto\x12\x13sentinel.deposit.v1\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a!sentinel/deposit/v1/deposit.proto"R\n\x14QueryDepositsRequest\x12:\n\npagination\x18\x01 \x01(\x0b2&.cosmos.base.query.v1beta1.PageRequest"&\n\x13QueryDepositRequest\x12\x0f\n\x07address\x18\x01 \x01(\t"\x8a\x01\n\x15QueryDepositsResponse\x124\n\x08deposits\x18\x01 \x03(\x0b2\x1c.sentinel.deposit.v1.DepositB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b2\'.cosmos.base.query.v1beta1.PageResponse"K\n\x14QueryDepositResponse\x123\n\x07deposit\x18\x01 \x01(\x0b2\x1c.sentinel.deposit.v1.DepositB\x04\xc8\xde\x1f\x002\x9f\x02\n\x0cQueryService\x12\x82\x01\n\rQueryDeposits\x12).sentinel.deposit.v1.QueryDepositsRequest\x1a*.sentinel.deposit.v1.QueryDepositsResponse"\x1a\x82\xd3\xe4\x93\x02\x14\x12\x12/sentinel/deposits\x12\x89\x01\n\x0cQueryDeposit\x12(.sentinel.deposit.v1.QueryDepositRequest\x1a).sentinel.deposit.v1.QueryDepositResponse"$\x82\xd3\xe4\x93\x02\x1e\x12\x1c/sentinel/deposits/{address}B:Z0github.com/sentinel-official/hub/x/deposit/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00b\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sentinel.deposit.v1.querier_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z0github.com/sentinel-official/hub/x/deposit/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00'
    _QUERYDEPOSITSRESPONSE.fields_by_name['deposits']._options = None
    _QUERYDEPOSITSRESPONSE.fields_by_name['deposits']._serialized_options = b'\xc8\xde\x1f\x00'
    _QUERYDEPOSITRESPONSE.fields_by_name['deposit']._options = None
    _QUERYDEPOSITRESPONSE.fields_by_name['deposit']._serialized_options = b'\xc8\xde\x1f\x00'
    _QUERYSERVICE.methods_by_name['QueryDeposits']._options = None
    _QUERYSERVICE.methods_by_name['QueryDeposits']._serialized_options = b'\x82\xd3\xe4\x93\x02\x14\x12\x12/sentinel/deposits'
    _QUERYSERVICE.methods_by_name['QueryDeposit']._options = None
    _QUERYSERVICE.methods_by_name['QueryDeposit']._serialized_options = b'\x82\xd3\xe4\x93\x02\x1e\x12\x1c/sentinel/deposits/{address}'
    _QUERYDEPOSITSREQUEST._serialized_start = 189
    _QUERYDEPOSITSREQUEST._serialized_end = 271
    _QUERYDEPOSITREQUEST._serialized_start = 273
    _QUERYDEPOSITREQUEST._serialized_end = 311
    _QUERYDEPOSITSRESPONSE._serialized_start = 314
    _QUERYDEPOSITSRESPONSE._serialized_end = 452
    _QUERYDEPOSITRESPONSE._serialized_start = 454
    _QUERYDEPOSITRESPONSE._serialized_end = 529
    _QUERYSERVICE._serialized_start = 532
    _QUERYSERVICE._serialized_end = 819




from google.api import annotations_pb2 as _annotations_pb2
from cosmos.base.query.v1beta1 import pagination_pb2 as _pagination_pb2
from cosmos.authz.v1beta1 import authz_pb2 as _authz_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union
DESCRIPTOR: _descriptor.FileDescriptor

class QueryGranteeGrantsRequest(_message.Message):
    __slots__ = ['grantee', 'pagination']
    GRANTEE_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    grantee: str
    pagination: _pagination_pb2.PageRequest

    def __init__(self, grantee: _Optional[str]=..., pagination: _Optional[_Union[(_pagination_pb2.PageRequest, _Mapping)]]=...) -> None:
        ...

class QueryGranteeGrantsResponse(_message.Message):
    __slots__ = ['grants', 'pagination']
    GRANTS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    grants: _containers.RepeatedCompositeFieldContainer[_authz_pb2.GrantAuthorization]
    pagination: _pagination_pb2.PageResponse

    def __init__(self, grants: _Optional[_Iterable[_Union[(_authz_pb2.GrantAuthorization, _Mapping)]]]=..., pagination: _Optional[_Union[(_pagination_pb2.PageResponse, _Mapping)]]=...) -> None:
        ...

class QueryGranterGrantsRequest(_message.Message):
    __slots__ = ['granter', 'pagination']
    GRANTER_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    granter: str
    pagination: _pagination_pb2.PageRequest

    def __init__(self, granter: _Optional[str]=..., pagination: _Optional[_Union[(_pagination_pb2.PageRequest, _Mapping)]]=...) -> None:
        ...

class QueryGranterGrantsResponse(_message.Message):
    __slots__ = ['grants', 'pagination']
    GRANTS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    grants: _containers.RepeatedCompositeFieldContainer[_authz_pb2.GrantAuthorization]
    pagination: _pagination_pb2.PageResponse

    def __init__(self, grants: _Optional[_Iterable[_Union[(_authz_pb2.GrantAuthorization, _Mapping)]]]=..., pagination: _Optional[_Union[(_pagination_pb2.PageResponse, _Mapping)]]=...) -> None:
        ...

class QueryGrantsRequest(_message.Message):
    __slots__ = ['grantee', 'granter', 'msg_type_url', 'pagination']
    GRANTEE_FIELD_NUMBER: _ClassVar[int]
    GRANTER_FIELD_NUMBER: _ClassVar[int]
    MSG_TYPE_URL_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    grantee: str
    granter: str
    msg_type_url: str
    pagination: _pagination_pb2.PageRequest

    def __init__(self, granter: _Optional[str]=..., grantee: _Optional[str]=..., msg_type_url: _Optional[str]=..., pagination: _Optional[_Union[(_pagination_pb2.PageRequest, _Mapping)]]=...) -> None:
        ...

class QueryGrantsResponse(_message.Message):
    __slots__ = ['grants', 'pagination']
    GRANTS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    grants: _containers.RepeatedCompositeFieldContainer[_authz_pb2.Grant]
    pagination: _pagination_pb2.PageResponse

    def __init__(self, grants: _Optional[_Iterable[_Union[(_authz_pb2.Grant, _Mapping)]]]=..., pagination: _Optional[_Union[(_pagination_pb2.PageResponse, _Mapping)]]=...) -> None:
        ...




from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional
DESCRIPTOR: _descriptor.FileDescriptor

class FungibleTokenPacketData(_message.Message):
    __slots__ = ['amount', 'denom', 'receiver', 'sender']
    AMOUNT_FIELD_NUMBER: _ClassVar[int]
    DENOM_FIELD_NUMBER: _ClassVar[int]
    RECEIVER_FIELD_NUMBER: _ClassVar[int]
    SENDER_FIELD_NUMBER: _ClassVar[int]
    amount: str
    denom: str
    receiver: str
    sender: str

    def __init__(self, denom: _Optional[str]=..., amount: _Optional[str]=..., sender: _Optional[str]=..., receiver: _Optional[str]=...) -> None:
        ...




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%sentinel/subscription/v2/params.proto\x12\x18sentinel.subscription.v2\x1a\x14gogoproto/gogo.proto\x1a\x1egoogle/protobuf/duration.proto"J\n\x06Params\x12@\n\x13status_change_delay\x18\x01 \x01(\x0b2\x19.google.protobuf.DurationB\x08\xc8\xde\x1f\x00\x98\xdf\x1f\x01B?Z5github.com/sentinel-official/hub/x/subscription/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00b\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sentinel.subscription.v2.params_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z5github.com/sentinel-official/hub/x/subscription/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00'
    _PARAMS.fields_by_name['status_change_delay']._options = None
    _PARAMS.fields_by_name['status_change_delay']._serialized_options = b'\xc8\xde\x1f\x00\x98\xdf\x1f\x01'
    _PARAMS._serialized_start = 121
    _PARAMS._serialized_end = 195




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from .....ibc.core.client.v1 import client_pb2 as ibc_dot_core_dot_client_dot_v1_dot_client__pb2
from .....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n ibc/core/client/v1/genesis.proto\x12\x12ibc.core.client.v1\x1a\x1fibc/core/client/v1/client.proto\x1a\x14gogoproto/gogo.proto"\xff\x03\n\x0cGenesisState\x12Z\n\x07clients\x18\x01 \x03(\x0b2).ibc.core.client.v1.IdentifiedClientStateB\x1e\xc8\xde\x1f\x00\xaa\xdf\x1f\x16IdentifiedClientStates\x12\x80\x01\n\x11clients_consensus\x18\x02 \x03(\x0b2).ibc.core.client.v1.ClientConsensusStatesB:\xc8\xde\x1f\x00\xaa\xdf\x1f\x16ClientsConsensusStates\xf2\xde\x1f\x18yaml:"clients_consensus"\x12h\n\x10clients_metadata\x18\x03 \x03(\x0b2-.ibc.core.client.v1.IdentifiedGenesisMetadataB\x1f\xc8\xde\x1f\x00\xf2\xde\x1f\x17yaml:"clients_metadata"\x120\n\x06params\x18\x04 \x01(\x0b2\x1a.ibc.core.client.v1.ParamsB\x04\xc8\xde\x1f\x00\x125\n\x10create_localhost\x18\x05 \x01(\x08B\x1b\xf2\xde\x1f\x17yaml:"create_localhost"\x12=\n\x14next_client_sequence\x18\x06 \x01(\x04B\x1f\xf2\xde\x1f\x1byaml:"next_client_sequence""3\n\x0fGenesisMetadata\x12\x0b\n\x03key\x18\x01 \x01(\x0c\x12\r\n\x05value\x18\x02 \x01(\x0c:\x04\x88\xa0\x1f\x00"\xa2\x01\n\x19IdentifiedGenesisMetadata\x12\'\n\tclient_id\x18\x01 \x01(\tB\x14\xf2\xde\x1f\x10yaml:"client_id"\x12\\\n\x0fclient_metadata\x18\x02 \x03(\x0b2#.ibc.core.client.v1.GenesisMetadataB\x1e\xc8\xde\x1f\x00\xf2\xde\x1f\x16yaml:"client_metadata"B:Z8github.com/cosmos/ibc-go/v3/modules/core/02-client/typesb\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.core.client.v1.genesis_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z8github.com/cosmos/ibc-go/v3/modules/core/02-client/types'
    _GENESISSTATE.fields_by_name['clients']._options = None
    _GENESISSTATE.fields_by_name['clients']._serialized_options = b'\xc8\xde\x1f\x00\xaa\xdf\x1f\x16IdentifiedClientStates'
    _GENESISSTATE.fields_by_name['clients_consensus']._options = None
    _GENESISSTATE.fields_by_name['clients_consensus']._serialized_options = b'\xc8\xde\x1f\x00\xaa\xdf\x1f\x16ClientsConsensusStates\xf2\xde\x1f\x18yaml:"clients_consensus"'
    _GENESISSTATE.fields_by_name['clients_metadata']._options = None
    _GENESISSTATE.fields_by_name['clients_metadata']._serialized_options = b'\xc8\xde\x1f\x00\xf2\xde\x1f\x17yaml:"clients_metadata"'
    _GENESISSTATE.fields_by_name['params']._options = None
    _GENESISSTATE.fields_by_name['params']._serialized_options = b'\xc8\xde\x1f\x00'
    _GENESISSTATE.fields_by_name['create_localhost']._options = None
    _GENESISSTATE.fields_by_name['create_localhost']._serialized_options = b'\xf2\xde\x1f\x17yaml:"create_localhost"'
    _GENESISSTATE.fields_by_name['next_client_sequence']._options = None
    _GENESISSTATE.fields_by_name['next_client_sequence']._serialized_options = b'\xf2\xde\x1f\x1byaml:"next_client_sequence"'
    _GENESISMETADATA._options = None
    _GENESISMETADATA._serialized_options = b'\x88\xa0\x1f\x00'
    _IDENTIFIEDGENESISMETADATA.fields_by_name['client_id']._options = None
    _IDENTIFIEDGENESISMETADATA.fields_by_name['client_id']._serialized_options = b'\xf2\xde\x1f\x10yaml:"client_id"'
    _IDENTIFIEDGENESISMETADATA.fields_by_name['client_metadata']._options = None
    _IDENTIFIEDGENESISMETADATA.fields_by_name['client_metadata']._serialized_options = b'\xc8\xde\x1f\x00\xf2\xde\x1f\x16yaml:"client_metadata"'
    _GENESISSTATE._serialized_start = 112
    _GENESISSTATE._serialized_end = 623
    _GENESISMETADATA._serialized_start = 625
    _GENESISMETADATA._serialized_end = 676
    _IDENTIFIEDGENESISMETADATA._serialized_start = 679
    _IDENTIFIEDGENESISMETADATA._serialized_end = 841




from gogoproto import gogo_pb2 as _gogo_pb2
from sentinel.swap.v1 import params_pb2 as _params_pb2
from sentinel.swap.v1 import swap_pb2 as _swap_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union
DESCRIPTOR: _descriptor.FileDescriptor

class GenesisState(_message.Message):
    __slots__ = ['params', 'swaps']
    PARAMS_FIELD_NUMBER: _ClassVar[int]
    SWAPS_FIELD_NUMBER: _ClassVar[int]
    params: _params_pb2.Params
    swaps: _containers.RepeatedCompositeFieldContainer[_swap_pb2.Swap]

    def __init__(self, swaps: _Optional[_Iterable[_Union[(_swap_pb2.Swap, _Mapping)]]]=..., params: _Optional[_Union[(_params_pb2.Params, _Mapping)]]=...) -> None:
        ...




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ...tendermint.p2p import types_pb2 as tendermint_dot_p2p_dot_types__pb2
from ...gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18tendermint/p2p/pex.proto\x12\x0etendermint.p2p\x1a\x1atendermint/p2p/types.proto\x1a\x14gogoproto/gogo.proto"\x0c\n\nPexRequest";\n\x08PexAddrs\x12/\n\x05addrs\x18\x01 \x03(\x0b2\x1a.tendermint.p2p.NetAddressB\x04\xc8\xde\x1f\x00"r\n\x07Message\x121\n\x0bpex_request\x18\x01 \x01(\x0b2\x1a.tendermint.p2p.PexRequestH\x00\x12-\n\tpex_addrs\x18\x02 \x01(\x0b2\x18.tendermint.p2p.PexAddrsH\x00B\x05\n\x03sumB7Z5github.com/tendermint/tendermint/proto/tendermint/p2pb\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tendermint.p2p.pex_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z5github.com/tendermint/tendermint/proto/tendermint/p2p'
    _PEXADDRS.fields_by_name['addrs']._options = None
    _PEXADDRS.fields_by_name['addrs']._serialized_options = b'\xc8\xde\x1f\x00'
    _PEXREQUEST._serialized_start = 94
    _PEXREQUEST._serialized_end = 106
    _PEXADDRS._serialized_start = 108
    _PEXADDRS._serialized_end = 167
    _MESSAGE._serialized_start = 169
    _MESSAGE._serialized_end = 283




from gogoproto import gogo_pb2 as _gogo_pb2
from cosmos.base.v1beta1 import coin_pb2 as _coin_pb2
from cosmos.bank.v1beta1 import bank_pb2 as _bank_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union
DESCRIPTOR: _descriptor.FileDescriptor

class MsgMultiSend(_message.Message):
    __slots__ = ['inputs', 'outputs']
    INPUTS_FIELD_NUMBER: _ClassVar[int]
    OUTPUTS_FIELD_NUMBER: _ClassVar[int]
    inputs: _containers.RepeatedCompositeFieldContainer[_bank_pb2.Input]
    outputs: _containers.RepeatedCompositeFieldContainer[_bank_pb2.Output]

    def __init__(self, inputs: _Optional[_Iterable[_Union[(_bank_pb2.Input, _Mapping)]]]=..., outputs: _Optional[_Iterable[_Union[(_bank_pb2.Output, _Mapping)]]]=...) -> None:
        ...

class MsgMultiSendResponse(_message.Message):
    __slots__ = []

    def __init__(self) -> None:
        ...

class MsgSend(_message.Message):
    __slots__ = ['amount', 'from_address', 'to_address']
    AMOUNT_FIELD_NUMBER: _ClassVar[int]
    FROM_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    TO_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    amount: _containers.RepeatedCompositeFieldContainer[_coin_pb2.Coin]
    from_address: str
    to_address: str

    def __init__(self, from_address: _Optional[str]=..., to_address: _Optional[str]=..., amount: _Optional[_Iterable[_Union[(_coin_pb2.Coin, _Mapping)]]]=...) -> None:
        ...

class MsgSendResponse(_message.Message):
    __slots__ = []

    def __init__(self) -> None:
        ...




from gogoproto import gogo_pb2 as _gogo_pb2
from cosmos.capability.v1beta1 import capability_pb2 as _capability_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union
DESCRIPTOR: _descriptor.FileDescriptor

class GenesisOwners(_message.Message):
    __slots__ = ['index', 'index_owners']
    INDEX_FIELD_NUMBER: _ClassVar[int]
    INDEX_OWNERS_FIELD_NUMBER: _ClassVar[int]
    index: int
    index_owners: _capability_pb2.CapabilityOwners

    def __init__(self, index: _Optional[int]=..., index_owners: _Optional[_Union[(_capability_pb2.CapabilityOwners, _Mapping)]]=...) -> None:
        ...

class GenesisState(_message.Message):
    __slots__ = ['index', 'owners']
    INDEX_FIELD_NUMBER: _ClassVar[int]
    OWNERS_FIELD_NUMBER: _ClassVar[int]
    index: int
    owners: _containers.RepeatedCompositeFieldContainer[GenesisOwners]

    def __init__(self, index: _Optional[int]=..., owners: _Optional[_Iterable[_Union[(GenesisOwners, _Mapping)]]]=...) -> None:
        ...




from gogoproto import gogo_pb2 as _gogo_pb2
from cosmos.crypto.multisig.v1beta1 import multisig_pb2 as _multisig_pb2
from cosmos.base.v1beta1 import coin_pb2 as _coin_pb2
from cosmos.tx.signing.v1beta1 import signing_pb2 as _signing_pb2
from google.protobuf import any_pb2 as _any_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union
DESCRIPTOR: _descriptor.FileDescriptor

class AuthInfo(_message.Message):
    __slots__ = ['fee', 'signer_infos']
    FEE_FIELD_NUMBER: _ClassVar[int]
    SIGNER_INFOS_FIELD_NUMBER: _ClassVar[int]
    fee: Fee
    signer_infos: _containers.RepeatedCompositeFieldContainer[SignerInfo]

    def __init__(self, signer_infos: _Optional[_Iterable[_Union[(SignerInfo, _Mapping)]]]=..., fee: _Optional[_Union[(Fee, _Mapping)]]=...) -> None:
        ...

class Fee(_message.Message):
    __slots__ = ['amount', 'gas_limit', 'granter', 'payer']
    AMOUNT_FIELD_NUMBER: _ClassVar[int]
    GAS_LIMIT_FIELD_NUMBER: _ClassVar[int]
    GRANTER_FIELD_NUMBER: _ClassVar[int]
    PAYER_FIELD_NUMBER: _ClassVar[int]
    amount: _containers.RepeatedCompositeFieldContainer[_coin_pb2.Coin]
    gas_limit: int
    granter: str
    payer: str

    def __init__(self, amount: _Optional[_Iterable[_Union[(_coin_pb2.Coin, _Mapping)]]]=..., gas_limit: _Optional[int]=..., payer: _Optional[str]=..., granter: _Optional[str]=...) -> None:
        ...

class ModeInfo(_message.Message):
    __slots__ = ['multi', 'single']

    class Multi(_message.Message):
        __slots__ = ['bitarray', 'mode_infos']
        BITARRAY_FIELD_NUMBER: _ClassVar[int]
        MODE_INFOS_FIELD_NUMBER: _ClassVar[int]
        bitarray: _multisig_pb2.CompactBitArray
        mode_infos: _containers.RepeatedCompositeFieldContainer[ModeInfo]

        def __init__(self, bitarray: _Optional[_Union[(_multisig_pb2.CompactBitArray, _Mapping)]]=..., mode_infos: _Optional[_Iterable[_Union[(ModeInfo, _Mapping)]]]=...) -> None:
            ...

    class Single(_message.Message):
        __slots__ = ['mode']
        MODE_FIELD_NUMBER: _ClassVar[int]
        mode: _signing_pb2.SignMode

        def __init__(self, mode: _Optional[_Union[(_signing_pb2.SignMode, str)]]=...) -> None:
            ...
    MULTI_FIELD_NUMBER: _ClassVar[int]
    SINGLE_FIELD_NUMBER: _ClassVar[int]
    multi: ModeInfo.Multi
    single: ModeInfo.Single

    def __init__(self, single: _Optional[_Union[(ModeInfo.Single, _Mapping)]]=..., multi: _Optional[_Union[(ModeInfo.Multi, _Mapping)]]=...) -> None:
        ...

class SignDoc(_message.Message):
    __slots__ = ['account_number', 'auth_info_bytes', 'body_bytes', 'chain_id']
    ACCOUNT_NUMBER_FIELD_NUMBER: _ClassVar[int]
    AUTH_INFO_BYTES_FIELD_NUMBER: _ClassVar[int]
    BODY_BYTES_FIELD_NUMBER: _ClassVar[int]
    CHAIN_ID_FIELD_NUMBER: _ClassVar[int]
    account_number: int
    auth_info_bytes: bytes
    body_bytes: bytes
    chain_id: str

    def __init__(self, body_bytes: _Optional[bytes]=..., auth_info_bytes: _Optional[bytes]=..., chain_id: _Optional[str]=..., account_number: _Optional[int]=...) -> None:
        ...

class SignerInfo(_message.Message):
    __slots__ = ['mode_info', 'public_key', 'sequence']
    MODE_INFO_FIELD_NUMBER: _ClassVar[int]
    PUBLIC_KEY_FIELD_NUMBER: _ClassVar[int]
    SEQUENCE_FIELD_NUMBER: _ClassVar[int]
    mode_info: ModeInfo
    public_key: _any_pb2.Any
    sequence: int

    def __init__(self, public_key: _Optional[_Union[(_any_pb2.Any, _Mapping)]]=..., mode_info: _Optional[_Union[(ModeInfo, _Mapping)]]=..., sequence: _Optional[int]=...) -> None:
        ...

class Tx(_message.Message):
    __slots__ = ['auth_info', 'body', 'signatures']
    AUTH_INFO_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    SIGNATURES_FIELD_NUMBER: _ClassVar[int]
    auth_info: AuthInfo
    body: TxBody
    signatures: _containers.RepeatedScalarFieldContainer[bytes]

    def __init__(self, body: _Optional[_Union[(TxBody, _Mapping)]]=..., auth_info: _Optional[_Union[(AuthInfo, _Mapping)]]=..., signatures: _Optional[_Iterable[bytes]]=...) -> None:
        ...

class TxBody(_message.Message):
    __slots__ = ['extension_options', 'memo', 'messages', 'non_critical_extension_options', 'timeout_height']
    EXTENSION_OPTIONS_FIELD_NUMBER: _ClassVar[int]
    MEMO_FIELD_NUMBER: _ClassVar[int]
    MESSAGES_FIELD_NUMBER: _ClassVar[int]
    NON_CRITICAL_EXTENSION_OPTIONS_FIELD_NUMBER: _ClassVar[int]
    TIMEOUT_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    extension_options: _containers.RepeatedCompositeFieldContainer[_any_pb2.Any]
    memo: str
    messages: _containers.RepeatedCompositeFieldContainer[_any_pb2.Any]
    non_critical_extension_options: _containers.RepeatedCompositeFieldContainer[_any_pb2.Any]
    timeout_height: int

    def __init__(self, messages: _Optional[_Iterable[_Union[(_any_pb2.Any, _Mapping)]]]=..., memo: _Optional[str]=..., timeout_height: _Optional[int]=..., extension_options: _Optional[_Iterable[_Union[(_any_pb2.Any, _Mapping)]]]=..., non_critical_extension_options: _Optional[_Iterable[_Union[(_any_pb2.Any, _Mapping)]]]=...) -> None:
        ...

class TxRaw(_message.Message):
    __slots__ = ['auth_info_bytes', 'body_bytes', 'signatures']
    AUTH_INFO_BYTES_FIELD_NUMBER: _ClassVar[int]
    BODY_BYTES_FIELD_NUMBER: _ClassVar[int]
    SIGNATURES_FIELD_NUMBER: _ClassVar[int]
    auth_info_bytes: bytes
    body_bytes: bytes
    signatures: _containers.RepeatedScalarFieldContainer[bytes]

    def __init__(self, body_bytes: _Optional[bytes]=..., auth_info_bytes: _Optional[bytes]=..., signatures: _Optional[_Iterable[bytes]]=...) -> None:
        ...



from . import allocation_pb2
from . import events_pb2
from . import genesis_pb2
from . import msg_pb2
from . import params_pb2
from . import payout_pb2
from . import querier_pb2
from . import subscription_pb2
